@@ -1,4 +1,4 @@
-# category.rb $Revision: 1.30 $
+# category.rb
 #
 # Copyright (c) 2003 Junichiro KITA <kita@kitaj.no-ip.com>
 # Distributed under the GPL
@@ -55,18 +55,23 @@ def category_anchor(category)
 		else
 			""
 		end
-	if @category_icon[category]
-		%Q|<a href="#{@index}?#{period_string}category=#{CGI::escape(category)}"><img class="category" src="#{@category_icon_url}#{@category_icon[category]}" alt="#{category}"></a>|
+	if @category_icon[category] and !@conf.mobile_agent?
+		%Q|<a href="#{h @index}?#{period_string}category=#{u category}"><img class="category" src="#{h @category_icon_url}#{h @category_icon[category]}" alt="#{h category}"></a>|
 	else
-		%Q|[<a href="#{@index}?#{period_string}category=#{CGI::escape(category)}">#{category}</a>]|
+		%Q|[<a href="#{h @index}?#{period_string}category=#{u category}">#{h category}</a>]|
 	end
 end
 
-def category_navi_anchor(info, label)
-	((!label.nil?) && label.empty?) ? '' : %Q[<span class="adminmenu">#{info.make_anchor(label)}</span>\n]
+def category_navi_anchor(info, label, mobile = false)
+	if mobile then
+		"|#{info.make_anchor(label)}"
+	else
+		((!label.nil?) && label.empty?) ? '' : %Q[<span class="adminmenu">#{info.make_anchor(label)}</span>\n]
+	end
 end
 
 def category_navi
+	mobile = @conf.mobile_agent?
 	info = Category::Info.new(@cgi, @years, @conf)
 	mode = info.mode
 
@@ -75,21 +80,23 @@ def category_navi
 	when :year, :half, :quarter, :month
 		all_diary = Category::Info.new(@cgi, @years, @conf, :year => -1, :month => -1)
 		all = Category::Info.new(@cgi, @years, @conf, :category => ['ALL'], :year => -1, :month => -1)
-		result << category_navi_anchor(info.prev, @conf['category.prev_' + mode.to_s])
-		result << category_navi_anchor(info.next, @conf['category.next_' + mode.to_s])
-		result << category_navi_anchor(all_diary, @conf['category.all_diary'])
-		result << category_navi_anchor(all, @conf['category.all'])
+		result << category_navi_anchor(info.prev, @conf['category.prev_' + mode.to_s], mobile)
+		result << category_navi_anchor(info.next, @conf['category.next_' + mode.to_s], mobile)
+		unless mobile then
+			result << category_navi_anchor(all_diary, @conf['category.all_diary'])
+			result << category_navi_anchor(all, @conf['category.all'])
+		end
 	when :all
 		year = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s)
 		half = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => "#{((Time.now.month - 1) / 6 + 1)}H")
 		quarter = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => "#{((Time.now.month - 1) / 3 + 1)}Q")
 		month = Category::Info.new(@cgi, @years, @conf, :year => Time.now.year.to_s, :month => '%02d' % Time.now.month)
-		result << category_navi_anchor(year, @conf['category.this_year'])
-		result << category_navi_anchor(half, @conf['category.this_half'])
-		result << category_navi_anchor(quarter, @conf['category.this_quarter'])
-		result << category_navi_anchor(month, @conf['category.this_month'])
+		result << category_navi_anchor(year, @conf['category.this_year'], mobile)
+		result << category_navi_anchor(half, @conf['category.this_half'], mobile)
+		result << category_navi_anchor(quarter, @conf['category.this_quarter'], mobile)
+		result << category_navi_anchor(month, @conf['category.this_month'], mobile)
 	end
-	if !info.category.include?('ALL')
+	if !info.category.include?('ALL') and !mobile then
 		all_category = Category::Info.new(@cgi, @years, @conf, :category => ['ALL'])
 		result << category_navi_anchor(all_category, @conf['category.all_category'])
 	end
@@ -102,10 +109,12 @@ def category_list_sections
 	years = info.years
 	r = ''
 
-	@categorized.keys.sort.each do |c|
+	raise ::TDiary::NotFound if @categorized.empty? and bot?
+
+	@categorized.keys.sort{|a,b| a.downcase <=> b.downcase}.each do |c|
 		info.category = c
 		if @category_icon[c]
-			img = %Q|<img class="category" src="#{@category_icon_url}#{@category_icon[c]}" alt="#{c}">|
+			img = %Q|<img class="category" src="#{h @category_icon_url}#{h @category_icon[c]}" alt="#{h c}">|
 		else
 			img = ''
 		end
@@ -113,16 +122,16 @@ def category_list_sections
 <div class="conf day">
 	<h2><span class="title">#{img}#{info.make_anchor}</span></h2>
 	<div class="body">
-		<p>
+		<ul class="category">
 HTML
-		@categorized[c].keys.sort.each do |ymd|
+		@categorized[c].keys.sort{|a,b| a.downcase <=> b.downcase}.each do |ymd|
 			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
 			@categorized[c][ymd].sort.each do |idx, title, excerpt|
-				r << %Q|\t\t\t<a href="#{@conf.index}#{anchor "#{ymd}#p#{'%02d' % idx}"}" title="#{excerpt}">#{text}#p#{'%02d' % idx}</a> #{apply_plugin(title)}<br>\n|
+				r << %Q|\t\t\t<li><a href="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}" title="#{h excerpt}">#{text}#p#{'%02d' % idx}</a> #{apply_plugin(title)}</li>\n|
 			end
 		end
 		r << <<HTML
-		</p>
+		</ul>
 	</div>
 </div>
 HTML
@@ -130,6 +139,29 @@ HTML
 	r
 end
 
+def category_list_sections_mobile
+	info = Category::Info.new(@cgi, @years, @conf)
+	category = info.category
+	years = info.years
+	r = ''
+
+	raise ::TDiary::NotFound if @categorized.empty? and bot?
+
+	@categorized.keys.sort{|a,b| a.downcase <=> b.downcase}.each do |c|
+		info.category = c
+		r << "<H2>#{info.make_anchor}</H2>"
+		r << "<UL>"
+		@categorized[c].keys.sort.each do |ymd|
+			text = Time.local(ymd[0,4], ymd[4,2], ymd[6,2]).strftime(@conf.date_format)
+			@categorized[c][ymd].sort.each do |idx, title, excerpt|
+				r << %Q|<LI><A HREF="#{h @index}#{anchor "#{ymd}#p#{'%02d' % idx}"}">#{text}#p#{'%02d' % idx}</A> #{apply_plugin(title)}</LI>\n|
+			end
+		end
+		r << "</UL>"
+	end
+	r
+end
+
 def category_list
 	info = Category::Info.new(@cgi, @years, @conf)
 	@categories.map do |c|
@@ -142,19 +174,28 @@ def category_dropdown_list(label = nil, multiple = nil)
 	label ||= 'Categorize!'
 	multiple ||= false
 
-	category = Category::Info.new(@cgi, @years, @conf).category
-	category = ['ALL'] if category.empty?
-
-	options = ''
-	(['ALL'] + @categories).each do |c|
-		options << %Q|\t\t<option value="#{CGI.escapeHTML(c)}"#{" selected" if category.include?(c)}>#{CGI.escapeHTML(c)}</option>\n|
+	info = Category::Info.new(@cgi, @years, @conf)
+	category = info.category
+	if category.empty?
+		return '' if @conf.mobile_agent?
+		category = ['ALL'] 
 	end
 
+	options = ''
+	(['ALL'] + @categories.sort{|a,b|a.downcase <=> b.downcase}).each do |c|
+		options << %Q|\t\t<option value="#{h c}"#{" selected" if category.include?(c)}>#{h c}</option>\n|
+	end
+
+	params = ''
+	params << %Q[<input type="hidden" name="year" value="#{h info.year}">] if info.year
+	params << %Q[<input type="hidden" name="month" value="#{h info.month}">] if info.month
+
 	<<HTML
-<form method="get" action="#{@conf.index}?#{period_string}"><div>
+<form method="get" action="#{h @index}"><div>
 	<select name="category"#{" multiple" if multiple}>
 #{options}
 	</select>
+	#{params}
 	<input type="submit" value="#{label}">
 </div></form>
 HTML
@@ -172,10 +213,25 @@ end
 
 module Category
 
+#
+# CGI (mock-up CGI class for Cache::recreate)
+#
+class CGI
+	attr_reader :params
+	def initialize
+		@params = Hash.new([])
+	end
+	def referer; nil; end
+	def user_agent; nil; end
+	def request_method; 'GET'; end
+end
+
 #
 # Info
 #
 class Info
+	include ERB::Util
+
 	def initialize(cgi, years, conf, args = {})
 		@cgi = cgi
 		@years = years
@@ -265,7 +321,7 @@ public
 	end
 
 	def make_anchor(label = nil)
-		a = @category.map {|c| "category=#{CGI.escape(c)}"}.join(';')
+		a = @category.map {|c| "category=#{u c}"}.join(';')
 		a << ";year=#{@year}" if @year
 		a << ";month=#{@month}" if @month
 		if label
@@ -277,9 +333,9 @@ public
 				label = label.gsub(/\$1/, @year || '*')
 			end
 		else
-			label = @category.map {|c| CGI.escapeHTML(c)}.join(':')
+			label = @category.map.to_a.join(':')
 		end
-		%Q|<a href="#{@conf.index}?#{a}">#{label}</a>|
+		%Q|<a href="#{h @conf.index}?#{h a}">#{h label}</a>|
 	end
 
 	#
@@ -359,6 +415,8 @@ end
 # Cache
 #
 class Cache
+	include ERB::Util
+
 	def initialize(conf, bind)
 		@conf = conf
 		@binding = bind                           # ...... very ugly
@@ -427,8 +485,7 @@ class Cache
 	# (re)create category cache
 	#
 	def recreate(years)
-		cgi = CGI::new
-		def cgi.referer; nil; end
+		cgi = Category::CGI::new
 
 		list = []
 		years.each do |y, ms|
@@ -464,18 +521,24 @@ class Cache
 		end
 
 		categorized = {}
-		categories.each do |c|
-			PStore.new(cache_file(c)).transaction do |db|
-				categorized[c] = db['category']
-				db.abort
-			end
-			categorized[c].keys.each do |ymd|
-				y, m = ymd[0,4], ymd[4,2]
-				if years[y].nil? or !years[y].include?(m)
-					categorized[c].delete(ymd)
+		begin
+			categorized.clear
+			categories.each do |c|
+				PStore.new(cache_file(c)).transaction do |db|
+					categorized[c] = db['category']
+					db.abort
 				end
+				categorized[c].keys.each do |ymd|
+					y, m = ymd[0,4], ymd[4,2]
+					if years[y].nil? or !years[y].include?(m)
+						categorized[c].delete(ymd)
+					end
+				end
+				categorized.delete(c) if categorized[c].empty?
 			end
-			categorized.delete(c) if categorized[c].empty?
+		rescue NoMethodError	# when categorized[c] is nil
+			recreate(years)
+			retry
 		end
 
 		categorized
@@ -484,7 +547,7 @@ class Cache
 private
 	def cache_file(category = nil)
 		if category
-			"#{@dir}/#{CGI.escape(category)}".untaint
+			"#{@dir}/#{u( category ).gsub(/%20/,'+')}".untaint
 		else
 			"#{@dir}/category_list"
 		end
@@ -553,19 +616,28 @@ end # module Category
 		ret << %Q[
 		<script type="text/javascript">
 		<!--
-		function inj_c(val){
-			target = window.document.forms[0].body
-			target.focus();
-			target.value += val
+		function inj_c(str) {
+			var textarea = window.document.forms[0].body;
+			textarea.focus();
+			if (document.selection) { // IE, Opera
+				var range = document.selection.createRange();
+				range.text = str;
+			} else if (textarea.selectionStart != undefined) { // mozilla
+				var start = textarea.selectionStart;
+				var end = textarea.selectionEnd;
+				textarea.value = textarea.value.substring(0, start) + str + textarea.value.substring(end);
+				textarea.setSelectionRange(start + str.length, start + str.length);
+			 } else {
+				textarea.value += str;
+			 }
 		}
 		//-->
 		</script>
 		]
 		ret << '<div class="field title">'
 		ret << "#{@category_conf_label}:\n"
-		@categories.each do |c|
-			e_c = CGI.escapeHTML(c)
-			ret << %Q!| <a href="javascript:inj_c(&quot;[#{e_c}]&quot;)">#{e_c}</a>\n!
+		@categories.sort{|a,b| a.downcase <=> b.downcase}.each do |c|
+			ret << %Q!| <a href="javascript:inj_c(&quot;[#{h c}]&quot;)">#{h c}</a>\n!
 		end
 		ret << "|\n</div>\n<br>\n"
 	end
@@ -576,14 +648,16 @@ end
 # when update diary, update cache
 #
 add_update_proc do
-	cache = @category_cache
-	list = []
-	diary = @diaries[@date.strftime('%Y%m%d')]
-	diary.each_section do |s|
-		list |= s.categories
+	if /^(append|replace)$/ =~ @mode
+		cache = @category_cache
+		list = []
+		diary = @diaries[@date.strftime('%Y%m%d')]
+		diary.each_section do |s|
+			list |= s.categories
+		end
+		cache.add_categories(list)
+		cache.replace_sections(diary)
 	end
-	cache.add_categories(list)
-	cache.replace_sections(diary)
 end
 
 
@@ -602,10 +676,10 @@ end
 def category_icon_select(category)
 	options = %Q|<\t<option value="none">#{@category_icon_none_label}</option>\n|
 	@category_all_icon.each do |i|
-		options << %Q|\t<option value="#{CGI.escapeHTML(i)}"#{" selected" if @category_icon[category] == i}>#{CGI.escapeHTML(i)}</option>\n|
+		options << %Q|\t<option value="#{h i}"#{" selected" if @category_icon[category] == i}>#{h i}</option>\n|
 	end
 	<<HTML
-<select name="category.icon.#{category}">
+<select name="category.icon.#{h category}">
 #{options}
 </select>
 HTML
@@ -613,7 +687,7 @@ end
 
 def category_icon_sample
 	@category_all_icon.map do |i|
-		%Q|<img src="#{@category_icon_url}#{i}" alt="#{i}" title="#{i}">\n|
+		%Q|<img src="#{h @category_icon_url}#{h i}" alt="#{h i}" title="#{h i}">\n|
 	end.join("/\n")
 end
 
@@ -650,7 +724,7 @@ if @mode == 'conf' || @mode == 'saveconf'
 			].each do |name|
 				@conf[name] = @conf.to_native( @cgi.params[name][0] )
 			end
-			if ["month", "quearter", "half", "year", "all"].index(@cgi.params["category.period"][0])
+			if ["month", "quarter", "half", "year", "all"].index(@cgi.params["category.period"][0])
 				@conf["category.period"] = @cgi.params["category.period"][0]
 			end
 			@conf['category.edit_support'] = (@cgi.params['category.edit_support'][0] == 'true')
