@@ -1,10 +1,11 @@
-# comment_rank.rb $Revision: 1.6 $
+# -*- coding: utf-8 -*-
+# comment_rank.rb
 #
-# comment_rank: ĥåߤοǥ󥭥
-#   ѥ᥿:
-#     max:  ɽ(̤:5)
-#     sep:  ѥ졼(̤:)
-#     except:        ̵뤹̾(Ĥ⤢,Ƕڤä¤٤)
+# comment_rank: ツッコミの数でランキング
+#   パラメタ:
+#     max:  最大表示数(未指定時:5)
+#     sep:  セパレータ(未指定時:空白)
+#     except:        無視する名前(いくつもある場合は,で区切って並べる)
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # You can distribute this file under the GPL2.
@@ -21,7 +22,7 @@ def comment_rank( max = 5, sep = '&nbsp;', *except )
 	result = []
 	name.sort{|a,b| (a[1])<=>(b[1])}.reverse.each_with_index do |ary,idx|
 		break if idx >= max
-		result << "<strong>#{idx+1}.</strong>#{CGI::escapeHTML( ary[0].to_s )}(#{ary[1].to_s})"
+		result << "<strong>#{idx+1}.</strong>#{h ary[0]}(#{ary[1].to_s})"
 	end
 	result.join( sep )
 end
