@@ -1,16 +1,17 @@
-# dropdown_calendar.rb $Revision: 1.4 $
+# -*- coding: utf-8 -*-
+# dropdown_calendar.rb
 #
-# calendar: ɥåץꥹȤ֤ץ饰
-#   ѥ᥿: ʤ
+# calendar: カレンダーをドロップダウンリストに置き換えるプラグイン
+#   パラメタ: なし
 #
 # 	Copyright (C) 2003 TADA Tadashi
 #	You can redistribute it and/or modify it under GPL2.
 #
 
-@dropdown_calendar_label = '' unless @resource_loaded
+@dropdown_calendar_label = '過去の日記' unless @resource_loaded
 
 def calendar
-	result = %Q[<form method="get" action="#{@index}">\n]
+	result = %Q[<form method="get" action="#{h @index}">\n]
 	result << %Q[<div class="calendar">#{@options['dropdown_calendar.label'] || @dropdown_calendar_label}\n]
 	result << %Q[<select name="date">\n]
 	@years.keys.sort.reverse_each do |year|
