@@ -6,9 +6,9 @@ def pb_show_conf_html
   <<-"HTML"
   <h3 class="subtitle">Pingback anchor</h3>
   #{"<p>Pingback anchor is inserted into begining of each Pingbacks from other weblogs. So You can specify '&lt;span class=\"tanchor\"&gt;_&lt;/span&gt;\">', image anchor will be shown Image anchor by themes.</p>" unless @conf.mobile_agent?}
-  <p><input name="trackback_anchor" value="#{ CGI::escapeHTML(@conf['trackback_anchor'] || @conf.comment_anchor ) }" size="40"></p>
+  <p><input name="trackback_anchor" value="#{ h(@conf['trackback_anchor'] || @conf.comment_anchor ) }" size="40"></p>
   <h3 class="subtitle">Number of Pingbacks</h3>
   #{"<p>In Latest or Month mode, you can specify number of visible Pingbacks. So in Dayly mode, all of Pingbacks are shown.</p>" unless @conf.mobile_agent?}
-  <p><input name="trackback_limit" value="#{ @conf['trackback_limit'] || @conf.comment_limit }" size="3"> Pingbacks</p>
+  <p><input name="trackback_limit" value="#{ h( @conf['trackback_limit'] || @conf.comment_limit )}" size="3"> Pingbacks</p>
   HTML
 end
