@@ -1,10 +1,11 @@
-# gradation.rb $Revision: 1.2 $
+# -*- coding: utf-8 -*-
+# gradation.rb
 #
-# gradation.rb: ʸ򥰥ǡɽ
-#   ѥ᥿:
-#     str:         ʸ
-#     first_color: ǡ󳫻Ͽ(16 6)
-#     last_color:  ǡλ(16 6)
+# gradation.rb: 文字列をグラデーション表示
+#   パラメタ:
+#     str:         文字列
+#     first_color: グラデーション開始色(16進 6桁指定)
+#     last_color:  グラデーション終了色(16進 6桁指定)
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # You can distribute this file under the GPL2.
@@ -21,7 +22,7 @@ def gradation( str, first_color, last_color )
 	bd = ((last_color[4..5].hex - b)/len)
 	ary.each do |x|
 		c = sprintf( '%02x%02x%02x', r, g, b )
-		result << %Q[<span style="color: ##{c}">#{x}</span>]
+		result << %Q[<span style="color: ##{c}">#{h x}</span>]
 		r += rd
 		g += gd
 		b += bd
