@@ -1,13 +1,14 @@
-# gradient.rb $Revision: 1.2 $
+# -*- coding: utf-8 -*-
+# gradient.rb
 #
-# gradient.rb: ʸ礭Ѳʤɽ
-#   ѥ᥿:
-#     str:        ʸ
-#     first_size: ʸ(͡ñpt)
-#     last_size:  ʸ(͡ñpt)
+# gradient.rb: 文字の大きさを変化させながら表示
+#   パラメタ:
+#     str:        文字列
+#     first_size: 開始文字サイズ(数値、単位pt)
+#     last_size:  開始文字サイズ(数値、単位pt)
 #
-#   : ֤ʤȤǤޤפ10pt30pt˳
-#     <%=gradient 'ʤȤǤޤ', 10, 30 %>
+#   例: 「こんなこともできます」を10ptから30ptに拡大
+#     <%=gradient 'こんなこともできます', 10, 30 %>
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # You can distribute this file under the GPL2.
@@ -20,7 +21,7 @@ def gradient( str, first_size, last_size )
 	sd = ( last_size - first_size ).to_f / len
 	ary.each do |x|
 		s = sprintf( '%d',fontsize.round )
-		result << %Q[<span style="font-size: #{s}pt;">#{x}</span>]
+		result << %Q[<span style="font-size: #{s}pt;">#{h x}</span>]
 		fontsize += sd
 	end
 	result
