@@ -1,14 +1,15 @@
-# makelirs.rb $Revision: 1.16 $
+# -*- coding: utf-8 -*-
+# makelirs.rb
 #
-# LIRSեޥåȤΥեǤФ
+# 更新情報をLIRSフォーマットのファイルに吐き出す
 #
-#   pluginǥ쥯ȥ֤ưޤ
+#   pluginディレクトリに置くだけで動作します。
 #
-#   tdiary.confˤơ@options['makelirs.file']
-#   ե̾ꤹȡΥե
-#   LIRSեȤޤ̵ˤindex.rbƱ
-#   ѥantenna.lirsȤեˤʤޤ
-#   ⡢WebФ񤭹븢¤ɬפǤ
+#   tdiary.confにおいて、@options['makelirs.file']に
+#   ファイル名を指定すると、そのファイルを出力先の
+#   LIRSファイルとします。無指定時にはindex.rbと同じ
+#   パスにantenna.lirsというファイルになります。
+#   いずれも、Webサーバから書き込める権限が必要です。
 #
 # Copyright (C) 2002 by Kazuhiro NISHIYAMA
 # You can redistribute it and/or modify it under GPL2.
@@ -60,16 +61,16 @@ add_update_proc do
 	t = TDiaryLatest::new( cgi, "latest.rhtml", conf )
 	body = t.eval_rhtml
 	# escape comma
-	e = proc{|str| str.gsub(/[,\\]/) { "\\#{$&}" } }
+	e = proc{|str| str.gsub(/[,\\]/){ "\\#{$&}" }.gsub( /[\r\n]/, '' ) }
 
 	now = Time.now
 	utc_offset = now.utc_offset
 
-	uri = @conf.index.dup
-	uri[0, 0] = @conf.base_url if %r|^https?://|i !~ @conf.index
+	uri = @index.dup
+	uri[0, 0] = @conf.base_url if %r|^https?://|i !~ @index
 	uri.gsub!( %r|/\./|, '/' )
 
-	lirs = "LIRS,#{t.last_modified.tv_sec},#{Time.now.tv_sec},#{utc_offset},#{body.size},#{uri},#{e[@html_title]},#{e[@author_name]},,\n"
+	lirs = "LIRS,#{t.last_modified.tv_sec},#{Time.now.tv_sec},#{utc_offset},#{body.size},#{e[uri]},#{e[@html_title]},#{e[@author_name]},,\n"
 	File::open( file, 'w' ) do |o|
 		o.puts lirs
 	end
