@@ -1,11 +1,13 @@
-# my-ex.rb $Revision: 1.16 $
+# -*- coding: utf-8 -*-
+# my-ex.rb
 #
-# my(ĥ): myץ饰ĥtitle°˻Ƥޤ
-#             褬ξ()֥ȥ
-#             ĥåߤξϥĥåͤ̾ƤΰȤޤ
-# ѥ᥿:
-#   a:   ʬΥ('YYYYMMDD#pNN' ޤ 'YYYYMMDD#cNN')
-#   str: 󥯤ˤʸ
+# my(拡張版): myプラグインを拡張し、title属性に参照先の内容を挿入します。
+#             参照先がセクションの場合は(あれば)サブタイトルを、
+#             ツッコミの場合はツッコんだ人の名前と内容の一部を使います。
+# パラメタ:
+#   a:   自分の日記内のリンク先情報('YYYYMMDD#pNN' または 'YYYYMMDD#cNN')
+#        URLをそのまま書くこともできます。
+#   str: リンクにする文字列
 #
 # Copyright (c) 2002 TADA Tadashi <sho@spc.gr.jp>
 # Distributed under the GPL
@@ -13,7 +15,7 @@
 unless @conf.mobile_agent?
 
 def my( a, str, title = nil )
-	date, noise, frag = a.scan( /^(\d{4}|\d{6}|\d{8}|\d{8}-\d+)([^\d]*)?#?([pct]\d+)?$/ )[0]
+	date, frag = a.scan( /(\d{4}|\d{6}|\d{8}|\d{8}-\d+)[^\d]*(?:#?([pct]\d+))?$/ )[0]
 	anc = frag ? "#{date}#{frag}" : date
 	place, frag = frag.scan( /([cpt])(\d\d)/ )[0] if frag
 	if date and frag and @diaries[date] then
@@ -27,14 +29,14 @@ def my( a, str, title = nil )
 				idx += 1
 			end
 			if section and section.subtitle then
-				title = CGI::escapeHTML( "#{apply_plugin(section.subtitle_to_html, true)}" )
+				title = h( "#{apply_plugin(section.subtitle_to_html, true)}" )
 				title.sub!( /^(\[([^\]]+)\])+ */, '' )
 			end
 		when 'c'
 			com = nil
 			@diaries[date].each_comment( frag.to_i ) {|c| com = c}
 			if com then
-				title = CGI::escapeHTML( "[#{com.name}] #{com.shorten( @conf.comment_length )}" )
+				title = h( "[#{com.name}] #{com.shorten( @conf.comment_length )}" )
 			end
 		when 't'
 			if @plugin_files.grep(/tb-show.rb\z/)
@@ -42,7 +44,7 @@ def my( a, str, title = nil )
 				@diaries[date].each_visible_trackback( frag.to_i ) {|t, idx| tb = t}
 				if tb then
 					url, name, tbtitle, excerpt = tb.body.split( /\n/,4 )
-					title = CGI::escapeHTML( "[#{name}] #{@conf.shorten( excerpt, @conf.comment_length )}" )
+					title = h( "[#{name}] #{@conf.shorten( excerpt, @conf.comment_length )}" )
 				end
 			end
 		end
@@ -50,9 +52,9 @@ def my( a, str, title = nil )
 	index = /^https?:/ =~ @index ? '' : @conf.base_url
 	index += @index.sub(%r|^\./|, '')
 	if title then
-		%Q[<a href="#{index}#{anchor anc}" title="#{title}">#{str}</a>]
+		%Q[<a href="#{h index}#{anchor anc}" title="#{title}">#{str}</a>]
 	else
-		%Q[<a href="#{index}#{anchor anc}">#{str}</a>]
+		%Q[<a href="#{h index}#{anchor anc}">#{str}</a>]
 	end
 end
 
