@@ -1,4 +1,4 @@
-# ping.rb: $Revision: 1.9 $
+# ping.rb
 #
 # ping to weblog ping servers.
 #
@@ -17,8 +17,8 @@ end
 def ping( list )
 	return unless @cgi.params['plugin_ping_send'][0] == 'true'
 
-	xml = @ping_encoder.call( <<-XML )
-<?xml version="1.0" encoding="#{@ping_encode}"?>
+	xml = to_utf8( <<-XML )
+<?xml version="1.0" encoding="UTF-8"?>
 <methodCall>
   <methodName>weblogUpdates.ping</methodName>
   <params>
@@ -71,9 +71,9 @@ def ping_conf_proc
 	result = <<-HTML
 		<h3>#{@ping_label_list}</h3>
 		<p>#{@ping_label_list_desc}</p>
-		<p><textarea name="ping.list" cols="70" rows="5">#{CGI::escapeHTML( @conf['ping.list'] )}</textarea></p>
+		<p><textarea name="ping.list" cols="70" rows="5">#{h( @conf['ping.list'] )}</textarea></p>
 		<h3>#{@ping_label_timeout}</h3>
-		<p><input type="text" name="ping.timeout" value="#{CGI::escapeHTML( @conf['ping.timeout'] )}" /></p>
+		<p><input type="text" name="ping.timeout" value="#{h( @conf['ping.timeout'] )}" /></p>
 	HTML
 end
 
@@ -87,10 +87,10 @@ def ping_edit_proc
 		checked = @cgi.params['plugin_ping_send'][0] == 'true' ? ' checked' : ''
 	end
 	r = <<-HTML
-	<div class="ping">
-	<input type="checkbox" name="plugin_ping_send" value="true"#{checked}  tabindex="400" />
+	<div class="ping"><label for="plugin_ping_send">
+	<input type="checkbox" id="plugin_ping_send" name="plugin_ping_send" value="true"#{checked}  tabindex="400">
 	#{@ping_label_send}
-	</div>
+	</label></div>
 	HTML
 end
 # vim: ts=3
