@@ -1,14 +1,15 @@
-# recent_namazu.rb $Revision 1.0 $
+# -*- coding: utf-8 -*-
+# recent_namazu.rb
 #
-# recent_namazu: Namazu쿷
-# 		 namazi.cgi븡ɥ(NMZ.slog)
-#		 ǿxxʬθɽޤ
-# ѥ᥿:
-#   file:       ɥե̾(Хѥɽ) 
-#   namazu:     ʤޤcgi̾ 
-#   limit:      ɽ(̤:5) 
-#   sep:        ѥ졼(̤:)
-#   make_link:  <a>뤫?(̤:)    
+# recent_namazu: Namazu検索語新しい順
+# 		 namazi.cgiが作成する検索キーワードログ(NMZ.slog)から
+#		 最新xx件分の検索語を表示します。
+# パラメタ:
+#   file:       検索キーワードログファイル名(絶対パス表記) 
+#   namazu:     なまずcgi名 
+#   limit:      表示件数(未指定時:5) 
+#   sep:        セパレータ(未指定時:空白)
+#   make_link:  <a>を生成するか?(未指定時:生成する)    
 #
 #
 # Copyright (c) 2002 Hiroyuki Ikezoe <zoe@kasumi.sakura.ne.jp>
@@ -30,9 +31,9 @@ def recent_namazu(file, namazu, limit = 5, sep='&nbsp;', make_link = true)
 			break if idx >= limit
 			word = line.split(/\t/)[0]
 			if make_link
-				result << %Q[<a href="#{namazu}?query=#{CGI::escapeHTML(word)}">#{CGI::escapeHTML(word)}</a>]
+				result << %Q[<a href="#{h( namazu )}?query=#{u( word )}">#{h( word )}</a>]
 			else
-				result << CGI::escapeHTML(word)
+				result << h( word )
 			end
 		end
 		result.join( sep )
