@@ -1,18 +1,19 @@
-# tlink.rb $Revision: 1.18 $
+# -*- coding: utf-8 -*-
+# tlink.rb
 #
-# title ° anchor plugin
+# title 属性付 anchor plugin
 #
-# Ȥ
-#   <%= tlink( "URL", "ʸ", "title °ȡʾάġ" ) %>
+# 使い方
+#   <%= tlink( "URL", "文字列", "title 属性の中身（省略可）" ) %>
 #
-#    3 ѥ᡼άURL  c#?? ʤС
-#   ΥĥåߤƤǽιԤɽޤ
-#    p#?? ʤС֥ȥ뤬Х֥ȥ뤬
-#   ʤкǽΥѥ饰դɽޤ
+#   第 3 パラメータを省略した時、URL の末尾が c#?? ならば、
+#   そのツッコミの内容が最初の行だけ表示されます。
+#   末尾が p#?? ならば、サブタイトルがあればサブタイトルが、
+#   なければ最初のパラグラフが表示されます。
 #
-#   . <%= tlink( "http://tdiary.tdiary.net/20020131.html#c01", "Υĥå" ) %>
-#       Ϸ:
-#       <a href="http://tdiary.tdiary.net/20020131.html#c01", title="ƥȤǤ">Υĥå</a>
+#   例. <%= tlink( "http://tdiary.tdiary.net/20020131.html#c01", "このツッコミ" ) %>
+#       出力結果:
+#       <a href="http://tdiary.tdiary.net/20020131.html#c01", title="テストでござるよ">このツッコミ</a>
 #
 # Copyright(C) 2002 NT <nt@24i.net>
 # Distributed under the GPL.
@@ -113,13 +114,13 @@ def tlink_getcomment( url )
     response , = http.get( "/#{path}", agent )
     response.body.each { |line|
       if %r[<A NAME="#{frag}] =~ line
-        if %r[<(?:P|H3)><A NAME="#{frag}">(?:.*?)</A> (.*?)</(?:P|H3)>] =~ line.toeuc
+        if %r[<(?:P|H3)><A NAME="#{frag}">(?:.*?)</A> (.*?)</(?:P|H3)>] =~ line.toutf8
           result = $1
           break
         else
           hata = 1
         end
-      elsif hata == 1 && %r[^\t*(.*?)<BR>] =~ line.toeuc
+      elsif hata == 1 && %r[^\t*(.*?)<BR>] =~ line.toutf8
         result = $1
         hata = 0
         break
@@ -150,6 +151,6 @@ def tlink( url, str, title = nil )
     end
   end
 
-  %Q[<a href="#{url}" title="#{title}">#{str}</a>]
+  %Q[<a href="#{h url}" title="#{h title}">#{str}</a>]
 end
 
