@@ -1,13 +1,12 @@
 #!/usr/bin/env ruby
-# xmlrpc.rb $Revision: 1.5 $
+# xmlrpc.rb
 #
 # Copyright (c) 2004 MoonWolf <moonwolf@moonwolf.com>
 # Distributed under the GPL
 #
 # require Ruby1.8 or xml-rpc(http://raa.ruby-lang.org/project/xml-rpc/)
-# require Uconv
 
-BEGIN { $defout.binmode }
+BEGIN { $stdout.binmode }
 $KCODE = 'n'
 
 if FileTest::symlink?( __FILE__ ) then
@@ -17,7 +16,6 @@ else
 end
 $:.unshift org_path.untaint
 require 'tdiary'
-require 'uconv'
 require 'uri'
 
 require 'xmlrpc/server'
@@ -27,57 +25,24 @@ else
   server = XMLRPC::CGIServer.new
 end
 
-RE_U301C = Regexp.compile("\343\200\234",false,"U")
-RE_U2016 = Regexp.compile("\342\200\226",false,"U")
-RE_U2212 = Regexp.compile("\342\210\222",false,"U")
-RE_U00A2 = Regexp.compile("\302\242",false,"U")
-RE_U00A3 = Regexp.compile("\302\243",false,"U")
-RE_U00AC = Regexp.compile("\302\254",false,"U")
-RE_UFF5E = Regexp.compile("\357\275\236",false,"U")
-RE_U2225 = Regexp.compile("\342\210\245",false,"U")
-RE_UFF0D = Regexp.compile("\357\274\215",false,"U")
-RE_UFFE0 = Regexp.compile("\357\277\240",false,"U")
-RE_UFFE1 = Regexp.compile("\357\277\241",false,"U")
-RE_UFFE2 = Regexp.compile("\357\277\242",false,"U")
-def euctou8(str)
-  str = Uconv.euctou8(str)
-  str.gsub!(RE_U301C,"\357\275\236")
-  str.gsub!(RE_U2016,"\342\210\245")
-  str.gsub!(RE_U2212,"\357\274\215")
-  str.gsub!(RE_U00A2,"\357\277\240")
-  str.gsub!(RE_U00A3,"\357\277\241")
-  str.gsub!(RE_U00AC,"\357\277\242")
-  str
-end
-
-def u8toeuc(str)
-  str = str.gsub(RE_UFF5E,"\343\200\234")
-  str.gsub!(RE_U2225,"\342\200\226")
-  str.gsub!(RE_UFF0D,"\342\210\222")
-  str.gsub!(RE_UFFE0,"\302\242")
-  str.gsub!(RE_UFFE1,"\302\243")
-  str.gsub!(RE_UFFE2,"\302\254")
-  Uconv.u8toeuc(str)
-end
-
 server.add_handler('blogger.newPost') do |appkey, blogid, username, password, content, publish|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  if username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  if username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     begin
       postid = Time.now.strftime("%Y%m%d")
       year, month, day = postid.scan(/(\d{4})(\d\d)(\d\d)/)[0]
       @cgi.params['date']  = [postid]
       tdiary = ::TDiary::TDiaryDay::new( @cgi, "day.rhtml", conf )
       time = Time::local( year, month, day ) + 12*60*60
-      diary = tdiary[time]
-      
+      diary = tdiary[time] || tdiary.instance_variable_get(:@io).diary_factory(time, '', '', conf.style)
+
       title,body = content.split(/\n/,2)
       index = diary.add_section(title, body)
       src = diary.to_src
       
-      ENV['REQUEST_METHOD'] = 'POST'
       @cgi.params.delete 'date'
       @cgi.params['old']   = [postid]
       @cgi.params['hide']  = diary.visible? ? [] : ['true']
@@ -86,6 +51,7 @@ server.add_handler('blogger.newPost') do |appkey, blogid, username, password, co
       @cgi.params['month'] = [postid[4..5]]
       @cgi.params['day']   = [postid[6..7]]
       @cgi.params['body']  = [src]
+      @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
       tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
       body = tdiary.eval_rhtml
       postid + "%02d" % index
@@ -98,10 +64,11 @@ server.add_handler('blogger.newPost') do |appkey, blogid, username, password, co
 end
 
 server.add_handler('blogger.editPost') do |appkey, postid, username, password, content, publish|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   begin
@@ -111,7 +78,6 @@ server.add_handler('blogger.editPost') do |appkey, postid, username, password, c
     index = index.to_i
     time = Time::local( year, month, day ) + 12*60*60
     diary = tdiary[time]
-    ENV['REQUEST_METHOD'] = 'POST'
     
     src = ''
     i = 0
@@ -120,7 +86,7 @@ server.add_handler('blogger.editPost') do |appkey, postid, username, password, c
       if i==index
         subtitle,body = content.split(/\n/,2)
         sec.subtitle = subtitle
-        sec.body     = body || ''
+        sec.body     = (body || '').sub(/[\n\r]+\Z/, '') + "\n\n"
       end
       src << sec.to_src
     }
@@ -133,43 +99,7 @@ server.add_handler('blogger.editPost') do |appkey, postid, username, password, c
     @cgi.params['month'] = [postid[4..5]]
     @cgi.params['day']   = [postid[6..7]]
     @cgi.params['body']  = [src]
-    tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
-    body = tdiary.eval_rhtml
-    true
-  rescue ::TDiary::ForceRedirect => redirect
-    true
-  rescue Exception
-    raise XMLRPC::FaultException.new(1,$!.to_s + "\n" + $!.backtrace.join("\n"))
-  end
-end
-
-server.add_handler('blogger.deletePost') do |appkey, postid, username, password, publish|
-  ENV['REQUEST_METHOD'] = 'POST'
-  @cgi = CGI::new
-  conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
-    raise XMLRPC::FaultException.new(1,'userid or password incorrect')
-  end
-  begin
-    year, month, day, index = postid.scan(/(\d{4})(\d\d)(\d\d)(\d\d)/)[0]
-    index = index.to_i
-    @cgi.params['date']  = [postid[0,8]]
-    tdiary = ::TDiary::TDiaryDay::new( @cgi, "day.rhtml", conf )
-    time = Time::local( year, month, day ) + 12*60*60
-    diary = tdiary[time]
-    
-    diary.delete_section(index)
-    src = diary.to_src
-    
-    ENV['REQUEST_METHOD'] = 'POST'
-    @cgi.params.delete 'date'
-    @cgi.params['old']   = [postid[0,8]]
-    @cgi.params['hide']  = diary.visible? ? [] : ['true']
-    @cgi.params['title'] = [diary.title]
-    @cgi.params['year']  = [postid[0..3]]
-    @cgi.params['month'] = [postid[4..5]]
-    @cgi.params['day']   = [postid[6..7]]
-    @cgi.params['body']  = [src]
+    @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
     tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
     body = tdiary.eval_rhtml
     true
@@ -181,10 +111,11 @@ server.add_handler('blogger.deletePost') do |appkey, postid, username, password,
 end
 
 server.add_handler('blogger.deletePost') do |appkey, postid, username, password|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   begin
@@ -198,7 +129,6 @@ server.add_handler('blogger.deletePost') do |appkey, postid, username, password|
     diary.delete_section(index)
     src = diary.to_src
     
-    ENV['REQUEST_METHOD'] = 'POST'
     @cgi.params.delete 'date'
     @cgi.params['old']   = [postid[0,8]]
     @cgi.params['hide']  = diary.visible? ? [] : ['true']
@@ -207,6 +137,7 @@ server.add_handler('blogger.deletePost') do |appkey, postid, username, password|
     @cgi.params['month'] = [postid[4..5]]
     @cgi.params['day']   = [postid[6..7]]
     @cgi.params['body']  = [src]
+    @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
     tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
     body = tdiary.eval_rhtml
     true
@@ -218,10 +149,9 @@ server.add_handler('blogger.deletePost') do |appkey, postid, username, password|
 end
 
 server.add_handler('blogger.getRecentPosts') do |appkey, blogid, username, password, numberOfPosts|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   result = []
@@ -235,12 +165,12 @@ server.add_handler('blogger.getRecentPosts') do |appkey, blogid, username, passw
     diary.each_section {|sec|
       index += 1
       postid = diary.date.strftime('%Y%m%d') + "%02d" % index
-      author = sec.author || euctou8(conf['xmlrpc.userid'])
+      author = sec.author || conf['xmlrpc.userid']
       body  = sec.subtitle + "\n" + sec.body
       result << {
         'postid'      => postid,
-        'userid'      => euctou8(author),
-        'content'     => euctou8(body),
+        'userid'      => author,
+        'content'     => body,
         'dateCreated' => diary.last_modified.utc
       }
     }
@@ -249,16 +179,15 @@ server.add_handler('blogger.getRecentPosts') do |appkey, blogid, username, passw
 end
 
 server.add_handler('blogger.getUsersBlogs') do |appkey, username, password|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   result = [
     {
       'blogid'   => conf['xmlrpc.blogid'],
-      'blogName' => euctou8(conf.html_title),
+      'blogName' => conf.html_title,
       'url'      => conf.base_url
     }
   ]
@@ -268,25 +197,26 @@ end
 server.add_handler('blogger.getUserInfo') do |appkey, username, password|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   result = {
-    'nickname'  => euctou8(conf.author_name),
+    'nickname'  => conf.author_name,
     'email'     => conf.author_mail,
     'url'       => conf.base_url,
-    'lastname'  => euctou8(conf['xmlrpc.lastname']),
-    'firstname' => euctou8(conf['xmlrpc.firstname']),
-    'userid'    => euctou8(conf['xmlrpc.userid'])
+    'lastname'  => conf['xmlrpc.lastname'],
+    'firstname' => conf['xmlrpc.firstname'],
+    'userid'    => conf['xmlrpc.userid']
   }
   result
 end
 
 server.add_handler('metaWeblog.newPost') do |blogid, username, password, content, publish|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   begin
@@ -295,12 +225,11 @@ server.add_handler('metaWeblog.newPost') do |blogid, username, password, content
     @cgi.params['date']  = [postid]
     tdiary = ::TDiary::TDiaryDay::new( @cgi, "day.rhtml", conf )
     time = Time::local( year, month, day ) + 12*60*60
-    diary = tdiary[time]
+    diary = tdiary[time] || tdiary.instance_variable_get(:@io).diary_factory(time, '', '', conf.style)
     
-    index = diary.add_section(u8toeuc(content['title']), u8toeuc(content['description']))
+    index = diary.add_section(content['title'], content['description'])
     src = diary.to_src
     
-    ENV['REQUEST_METHOD'] = 'POST'
     @cgi.params.delete 'date'
     @cgi.params['old']   = [postid]
     @cgi.params['hide']  = diary.visible? ? [] : ['true']
@@ -309,6 +238,7 @@ server.add_handler('metaWeblog.newPost') do |blogid, username, password, content
     @cgi.params['month'] = [postid[4..5]]
     @cgi.params['day']   = [postid[6..7]]
     @cgi.params['body']  = [src]
+    @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
     tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
     body = tdiary.eval_rhtml
     postid + "%02d" % index
@@ -318,10 +248,11 @@ server.add_handler('metaWeblog.newPost') do |blogid, username, password, content
 end
 
 server.add_handler('metaWeblog.editPost') do |postid, username, password, content, publish|
-  ENV['REQUEST_METHOD'] = 'POST'
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   begin
@@ -331,15 +262,14 @@ server.add_handler('metaWeblog.editPost') do |postid, username, password, conten
     index = index.to_i
     time = Time::local( year, month, day ) + 12*60*60
     diary = tdiary[time]
-    ENV['REQUEST_METHOD'] = 'POST'
     
     src = ''
     i = 0
     diary.each_section {|sec|
       i += 1
       if i==index
-        sec.subtitle = u8toeuc(content['title'])
-        sec.body     = u8toeuc(content['description'])
+        sec.subtitle = content['title']
+        sec.body     = content['description'] || ''.sub(/[\n\r]+\Z/, '') + "\n\n"
       end
       src << sec.to_src
     }
@@ -352,6 +282,7 @@ server.add_handler('metaWeblog.editPost') do |postid, username, password, conten
     @cgi.params['month'] = [postid[4..5]]
     @cgi.params['day']   = [postid[6..7]]
     @cgi.params['body']  = [src]
+    @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
     tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
     body = tdiary.eval_rhtml
     true
@@ -365,7 +296,7 @@ end
 server.add_handler('metaWeblog.getPost') do |postid, username, password|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   @cgi.params['date'] = [postid[0,8]]
@@ -383,11 +314,11 @@ server.add_handler('metaWeblog.getPost') do |postid, username, password|
       title = sec.stripped_subtitle || ''
       body  = sec.body
       result = {
-        'userid'       => euctou8(conf['xmlrpc.userid']),
+        'userid'       => conf['xmlrpc.userid'],
         'dateCreated'  => diary.last_modified.utc,
         'postid'       => postid,
-        'description'  => euctou8(body),
-        'title'        => euctou8(title),
+        'description'  => body,
+        'title'        => title,
         'link'         => link,
         'permaLink'    => link,
         'mt_excerpt'   => '',
@@ -406,7 +337,7 @@ end
 server.add_handler('metaWeblog.getRecentPosts') do |blogid, username, password, numberOfPosts|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   result = []
@@ -423,13 +354,13 @@ server.add_handler('metaWeblog.getRecentPosts') do |blogid, username, password,
       link = conf.base_url + conf.index.sub(%r|^\./|, '') + diary.date.strftime('%Y%m%d') + ".html\#p%02d" % index
       title = sec.stripped_subtitle || ''
       body  = sec.body
-      author = sec.author || euctou8(conf['xmlrpc.userid'])
+      author = sec.author || conf['xmlrpc.userid']
       result << {
         'dateCreated'       => diary.last_modified.utc,
-        'userid'            => euctou8(author),
+        'userid'            => author,
         'postid'            => postid,
-        'description'       => euctou8(body),
-        'title'             => euctou8(title),
+        'description'       => body,
+        'title'             => title,
         'link'              => link,
         'permaLink'         => link,
         'mt_excerpt'        => '',
@@ -447,7 +378,7 @@ end
 server.add_handler('metaWeblog.newMediaObject') do |blogid, username, password, file|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   image_dir = conf['image.dir'] || './images/'
@@ -466,7 +397,7 @@ end
 server.add_handler('mt.getRecentPostTitles') do |blogid, username, password, numberOfPosts|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   result = []
@@ -480,12 +411,12 @@ server.add_handler('mt.getRecentPostTitles') do |blogid, username, password, num
     diary.each_section {|sec|
       index += 1
       postid = diary.date.strftime('%Y%m%d') + "%02d" % index
-      author = sec.author || euctou8(conf['xmlrpc.userid'])
+      author = sec.author || conf['xmlrpc.userid']
       result << {
         'dateCreated'       => diary.last_modified.utc,
-        'userid'            => euctou8(author),
+        'userid'            => author,
         'postid'            => postid,
-        'title'             => euctou8(sec.subtitle),
+        'title'             => sec.subtitle,
       }
     }
   }
@@ -495,7 +426,7 @@ end
 server.add_handler('mt.getCategoryList') do |blogid, username, password|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   @cgi.params['date'] = [Time.now.strftime('%Y%m%d')]
@@ -519,8 +450,8 @@ server.add_handler('mt.getCategoryList') do |blogid, username, password|
   result = []
   list.each {|c|
     result << {
-      'categoryId'   => euctou8(c),
-      'categoryName' => euctou8(c)
+      'categoryId'   => c,
+      'categoryName' => c
     }
   }
   result
@@ -529,7 +460,7 @@ end
 server.add_handler('mt.getPostCategories') do |postid, username, password|
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   @cgi.params['date'] = [postid[0,8]]
@@ -545,8 +476,8 @@ server.add_handler('mt.getPostCategories') do |postid, username, password|
     if i==index
       sec.categories.each_with_index {|cat,j|
         result << {
-          'categoryName' => euctou8(cat),
-          'categoryId'   => euctou8(cat),
+          'categoryName' => cat,
+          'categoryId'   => cat,
           'isPrimary'    => j==0
         }
       }
@@ -557,10 +488,11 @@ server.add_handler('mt.getPostCategories') do |postid, username, password|
 end
 
 server.add_handler('mt.setPostCategories') do |postid, username, password, categories|
-  STDERR.puts categories.inspect
   @cgi = CGI::new
   conf = ::TDiary::Config::new(@cgi)
-  unless username==euctou8(conf['xmlrpc.username']) && password==euctou8(conf['xmlrpc.password'])
+  ENV['REQUEST_METHOD'] = 'POST'
+  ENV['HTTP_REFERER'] = (URI.parse(conf.base_url) + conf.update).to_s
+  unless username==conf['xmlrpc.username'] && password==conf['xmlrpc.password']
     raise XMLRPC::FaultException.new(1,'userid or password incorrect')
   end
   begin
@@ -570,7 +502,7 @@ server.add_handler('mt.setPostCategories') do |postid, username, password, categ
     index = index.to_i
     time = Time::local( year, month, day ) + 12*60*60
     diary = tdiary[time]
-    ENV['REQUEST_METHOD'] = 'POST'
+
     @cgi.params.delete 'date'
     
     src = ''
@@ -596,6 +528,7 @@ server.add_handler('mt.setPostCategories') do |postid, username, password, categ
     @cgi.params['month'] = [postid[4..5]]
     @cgi.params['day']   = [postid[6..7]]
     @cgi.params['body']  = [src]
+    @cgi.params['csrf_protection_key']  = [conf.options['csrf_protection_key']]
     tdiary = ::TDiary::TDiaryReplace::new( @cgi, 'show.rhtml', conf )
     body = tdiary.eval_rhtml
     true
@@ -645,7 +578,7 @@ server.add_handler('mt.getTrackbackPings') do |postid|
     result << {
       'pingURL'   => url,
       'pingIP'    => '127.0.0.1',
-      'pingTitle' => euctou8(title),
+      'pingTitle' => title,
     }
   }
   result
