@@ -1,6 +1,5 @@
-# English resource of tb-send.rb
+# Chinese resource of tb-send.rb
 
-@tb_send_ping_charset = 'UTF-8'
 @tb_send_label_url = 'Send TrackBack to'
 @tb_send_label_section = 'Section of TrackBack source'
 @tb_send_label_no_section = '(no section specify)'
