@@ -1,11 +1,32 @@
+# -*- coding: utf-8; -*-
 #
 # 00default.rb: default plugins 
-# $Revision: 1.97 $
+# $Revision: 1.120 $
 #
 # Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
+#
+# setting @date
+#
+unless @date
+	if @diary then
+		@date = @diary.date
+	else
+		@date = case @mode
+		when 'day'
+			Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)/ ).flatten )
+		when 'month'
+			Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)/ ).flatten )
+		when 'edit'
+			Time::local( @cgi.params['year'][0].to_i, @cgi.params['month'][0].to_i, @cgi.params['day'][0].to_i )
+		else
+			nil
+		end
+	end
+end
+
 #
 # make navigation buttons
 #
@@ -16,8 +37,10 @@ def navi
 	result << %Q[</div>]
 end
 
-def navi_item( link, label )
-	%Q[<span class="adminmenu"><a href="#{link}">#{label}</a></span>\n]
+def navi_item( link, label, rel = nil )
+	result = %Q[<span class="adminmenu"><a href="#{link}"]
+	result << %Q[ rel="#{rel}"] if rel
+	result << %Q[>#{label}</a></span>\n]
 end
 
 def navi_user
@@ -42,23 +65,23 @@ end
 
 def navi_user_default
 	result = ''
-	result << navi_item( @index_page, navi_index ) unless @index_page.empty?
+	result << navi_item( h(@index_page), h(navi_index) ) unless @index_page.empty?
 	result
 end
 
 def navi_user_latest
 	result = ''
-	result << navi_item( "#{@index}#{anchor( @conf['ndays.prev'] + '-' + @conf.latest_limit.to_s )}", "&laquo;#{navi_prev_ndays}" ) if @conf['ndays.prev'] and not bot?
-	result << navi_item( @index, navi_latest ) if @cgi.params['date'][0]
-	result << navi_item( "#{@index}#{anchor( @conf['ndays.next'] + '-' + @conf.latest_limit.to_s )}", "#{navi_next_ndays}&raquo;" ) if @conf['ndays.next'] and not bot?
+	result << navi_item( "#{h @index}#{anchor( @conf['ndays.prev'] + '-' + @conf.latest_limit.to_s )}", "&laquo;#{navi_prev_ndays}", "next" ) if @conf['ndays.prev'] and not bot?
+	result << navi_item( h(@index), h(navi_latest) ) if @cgi.params['date'][0]
+	result << navi_item( "#{h @index}#{anchor( @conf['ndays.next'] + '-' + @conf.latest_limit.to_s )}", "#{navi_next_ndays}&raquo;", "prev") if @conf['ndays.next'] and not bot?
 	result
 end
 
 def navi_user_day
 	result = ''
-	result << navi_item( "#{@index}#{anchor @prev_day}", "&laquo;#{navi_prev_diary Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" ) if @prev_day
+	result << navi_item( "#{h @index}#{anchor @prev_day}", "&laquo;#{h navi_prev_diary(Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}" ) if @prev_day
 	result << navi_item( @index, navi_latest )
-	result << navi_item( "#{@index}#{anchor @next_day}", "#{navi_next_diary Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}&raquo;" ) if @next_day
+	result << navi_item( "#{h @index}#{anchor @next_day}", "#{h navi_next_diary(Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}&raquo;" ) if @next_day
 	result
 end
 
@@ -74,17 +97,17 @@ def navi_user_month
 	next_month = ym[ym.index( now )+1]
 
 	result = ''
-	result << navi_item( "#{@index}#{anchor( prev_month )}", "&laquo;#{navi_prev_month}" ) if prev_month and not bot?
-	result << navi_item( @index, navi_latest )
-	result << navi_item( "#{@index}#{anchor( next_month )}", "#{navi_next_month}&raquo;" ) if next_month and not bot?
+	result << navi_item( "#{h @index}#{anchor( prev_month )}", "&laquo;#{h navi_prev_month}" ) if prev_month and not bot?
+	result << navi_item( h(@index), h(navi_latest) )
+	result << navi_item( "#{h @index}#{anchor( next_month )}", "#{h navi_next_month}&raquo;" ) if next_month and not bot?
 	result
 end
 
 def navi_user_nyear
 	result = ''
-	result << navi_item( "#{@index}#{anchor @prev_day[4,4]}", "&laquo;#{navi_prev_nyear Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" ) if @prev_day
-	result << navi_item( @index, navi_latest ) unless @mode == 'latest'
-	result << navi_item( "#{@index}#{anchor @next_day[4,4]}", "#{navi_next_nyear Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}&raquo;" ) if @next_day
+	result << navi_item( "#{h @index}#{anchor @prev_day[4,4]}", "&laquo;#{h navi_prev_nyear(Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}" ) if @prev_day
+	result << navi_item( h(@index), h(navi_latest) ) unless @mode == 'latest'
+	result << navi_item( "#{h @index}#{anchor @next_day[4,4]}", "#{h navi_next_nyear(Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}&raquo;" ) if @next_day
 	result
 end
 
@@ -92,47 +115,48 @@ def navi_user_edit
 	result = ''
 	if @prev_day then
 		a = @prev_day.scan( /^(\d{4})(\d\d)(\d\d)$/ ).flatten
-		result << navi_item( "#{@update}?edit=true;year=#{a[0]};month=#{a[1]};day=#{a[2]}", "&laquo;#{navi_prev_diary Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" )
+		result << navi_item( "#{h @update}?edit=true;year=#{a[0]};month=#{a[1]};day=#{a[2]}", "&laquo;#{h navi_prev_diary(Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}" )
 	end
-	result << navi_item( @index, navi_latest )
+	result << navi_item( h(@index), h(navi_latest) )
 	if @next_day then
 		a = @next_day.scan( /^(\d{4})(\d\d)(\d\d)$/ ).flatten
-		result << navi_item( "#{@update}?edit=true;year=#{a[0]};month=#{a[1]};day=#{a[2]}", "#{navi_next_diary Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}&raquo;" )
+		result << navi_item( "#{h @update}?edit=true;year=#{a[0]};month=#{a[1]};day=#{a[2]}", "#{h navi_next_diary(Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]))}&raquo;" )
 	end
 	result
 end
 
 def navi_user_else
-	navi_item( @index, navi_latest )
+	navi_item( h(@index), h(navi_latest) )
 end
 
 def navi_admin
 	if @mode == 'day' then
-		result = navi_item( "#{@update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}", navi_edit )
+		result = navi_item( "#{h @update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}", h(navi_edit), "nofollow" )
 	else
-		result = navi_item( @update, navi_update )
+		result = navi_item( h(@update), h(navi_update), "nofollow")
 	end
-	result << navi_item( "#{@update}?conf=default", navi_preference ) if /^(latest|month|day|comment|conf|nyear|category.*)$/ !~ @mode
+	result << navi_item( "#{h @update}?conf=default", h(navi_preference) ) if /^(latest|month|day|comment|conf|nyear|category.*)$/ !~ @mode
 	result
 end
 
 def mobile_navi
 	calc_links
 	result = []
-	i = 1
 	if @prev_day
-		result << %Q[<A HREF="#{@index}#{anchor @prev_day}" ACCESSKEY="#{i}">[#{i}]#{mobile_navi_prev_diary}</A>]
-		i += 1
+		result << %Q[<A HREF="#{h @index}#{anchor @prev_day}" ACCESSKEY="*">[*]#{mobile_navi_prev_diary}</A>]
 	end
 	if @mode != 'latest'
-		result << %Q[<A HREF="#{@index}" ACCESSKEY="#{i}">[#{i}]#{mobile_navi_latest}</A>]
-		i += 1
+		result << %Q[<A HREF="#{h @index}" ACCESSKEY="0">[0]#{mobile_navi_latest}</A>]
 	end
 	if @next_day
-		result << %Q[<A HREF="#{@index}#{anchor @next_day}" ACCESSKEY="#{i}">[#{i}]#{mobile_navi_next_diary}</A>]
+		result << %Q[<A HREF="#{h @index}#{anchor @next_day}" ACCESSKEY="#">[#]#{mobile_navi_next_diary}</A>]
 	end
-	result << %Q[<A HREF="#{@update}" ACCESSKEY="0">[0]#{mobile_navi_update}</A>]
-	result << %Q[<A HREF="#{@update}?conf=default" ACCESSKEY="9">[9]#{mobile_navi_preference}</A>] unless /^(latest|month|day|conf|nyear)$/ === @mode
+	if @mode == 'day' then
+		result << %Q[<A HREF="#{h @update}?edit=true;year=#{@date.year};month=#{@date.month};day=#{@date.day}" ACCESSKEY="5">[5]#{mobile_navi_edit}</A>]
+	else
+		result << %Q[<A HREF="#{h @update}" ACCESSKEY="5">[5]#{mobile_navi_update}</A>]
+	end
+	result << %Q[<A HREF="#{h @update}?conf=default" ACCESSKEY="8">[8]#{mobile_navi_preference}</A>] unless /^(latest|month|day|conf|nyear)$/ === @mode
 	result.join('|')
 end
 
@@ -145,7 +169,7 @@ def calendar
 		result << %Q[<div class="year">#{year}|]
 		@years[year.to_s].sort.each do |month|
 			m = "#{year}#{month}"
-			result << %Q[<a href="#{@index}#{anchor m}">#{month}</a>|]
+			result << %Q[<a href="#{h @index}#{anchor m}">#{month}</a>|]
 		end
 		result << "</div>\n"
 	end
@@ -159,7 +183,7 @@ def insert( file )
 	begin
 		File::readlines( file ).join
 	rescue
-		%Q[<p class="message">#$! (#{$!.class})<br>cannot read #{file}.</p>]
+		%Q[<p class="message">#$! (#{h $!.class})<br>cannot read #{h file}.</p>]
 	end
 end
 
@@ -176,8 +200,8 @@ end
 add_header_proc do
 	calc_links
 	<<-HEADER
-	<meta http-equiv="Content-Type" content="text/html; charset=#{charset}">
-	<meta name="generator" content="tDiary #{TDIARY_VERSION}">
+	<meta http-equiv="Content-Type" content="text/html; charset=#{h charset}">
+	<meta name="generator" content="tDiary #{h TDIARY_VERSION}">
 	#{last_modified_header}
 	#{content_script_type}
 	#{author_name_tag}
@@ -187,6 +211,7 @@ add_header_proc do
 	#{icon_tag}
 	#{description_tag}
 	#{css_tag.chomp}
+	#{iphone_tag.chomp}
 	#{title_tag.chomp}
 	#{robot_control.chomp}
 	HEADER
@@ -217,8 +242,10 @@ def calc_links
 		days.sort!
 		days.unshift(nil).push(nil)
 
-		days.index( today ).times do |i|
-			@prev_day = days[days.index( today ) - i - 1]
+		current_date = @date.strftime( '%Y%m%d' )
+		days[0 .. days.index( today ) - 1].reverse_each do |d|
+		 	@prev_day = d
+			next if @mode == 'latest' and current_date == d
 			break unless @prev_day
 			break if (@mode == 'edit') or @diaries[@prev_day].visible?
 		end
@@ -232,8 +259,8 @@ def calc_links
 			@prev_day = (Time.local(y, m, 1) - 24*60*60).strftime( '%Y%m%d' )
 		end
 
-		days.index( today ).times do |i|
-			@next_day = days[days.index( today ) + i + 1]
+		days[days.index( today ) + 1 .. -1].each do |d|
+			@next_day = d
 			break unless @next_day
 			break if (@mode == 'edit') or @diaries[@next_day].visible?
 		end
@@ -266,12 +293,12 @@ def last_modified_header
 end
 
 def content_script_type
-	%Q[<meta http-equiv="Content-Script-Type" content="text/javascript; charset=#{charset}">]
+	%Q[<meta http-equiv="Content-Script-Type" content="text/javascript; charset=#{h charset}">]
 end
 
 def author_name_tag
 	if @author_name and not(@author_name.empty?) then
-		%Q[<meta name="author" content="#{@author_name}">]
+		%Q[<meta name="author" content="#{h @author_name}">]
 	else
 		''
 	end
@@ -279,7 +306,7 @@ end
 
 def author_mail_tag
 	if @author_mail and not(@author_mail.empty?) then
-		%Q[<link rev="made" href="mailto:#{@author_mail}">]
+		%Q[<link rev="made" href="mailto:#{h @author_mail}">]
 	else
 		''
 	end
@@ -288,25 +315,25 @@ end
 def index_page_tag
 	result = ''
 	if @index_page and @index_page.size > 0 then
-		result << %Q[<link rel="index" title="#{navi_index}" href="#{@index_page}">\n\t]
+		result << %Q[<link rel="index" title="#{h navi_index}" href="#{h @index_page}">\n\t]
 	end
 	if @prev_day then
 		case @mode
 		when 'day'
-			result << %Q[<link rel="prev" title="#{navi_prev_diary Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" href="#{@index}#{anchor @prev_day}">\n\t]
+			result << %Q[<link rel="prev" title="#{navi_prev_diary( Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]) )}" href="#{h @index}#{anchor @prev_day}">\n\t]
 		when 'nyear'
-			result << %Q[<link rel="prev" title="#{navi_prev_nyear Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" href="#{@index}#{anchor @prev_day[4,4]}">\n\t]
+			result << %Q[<link rel="prev" title="#{navi_prev_nyear( Time::local(*@prev_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]) )}" href="#{h @index}#{anchor @prev_day[4,4]}">\n\t]
 		end
 	end
 	if @next_day then
 		case @mode
 		when 'day'
-			result << %Q[<link rel="next" title="#{navi_next_diary Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" href="#{@index}#{anchor @next_day}">\n\t]
+			result << %Q[<link rel="next" title="#{navi_next_diary( Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]) )}" href="#{h @index}#{anchor @next_day}">\n\t]
 		when 'nyear'
-			result << %Q[<link rel="next" title="#{navi_next_nyear Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0])}" href="#{@index}#{anchor @next_day[4,4]}">\n\t]
+			result << %Q[<link rel="next" title="#{h navi_next_nyear( Time::local(*@next_day.scan(/^(\d{4})(\d\d)(\d\d)$/)[0]) )}" href="#{h @index}#{anchor @next_day[4,4]}">\n\t]
 		end
 	end
-	result << %Q[<link rel="start" title="#{navi_latest}" href="#{@index}">\n\t]
+	result << %Q[<link rel="start" title="#{navi_latest}" href="#{h @index}">\n\t]
 	result.chop.chop
 end
 
@@ -318,15 +345,15 @@ def mobile_link_discovery
 	if @mode == 'day' then
 		uri += anchor( @date.strftime( '%Y%m%d' ) )
 	end
-	%Q[<link rel="alternate" media="handheld" type="text/html" href="#{uri}">]
+	%Q[<link rel="alternate" media="handheld" type="text/html" href="#{h uri}">]
 end
 
 def icon_tag
 	if @conf.icon and not(@conf.icon.empty?) then
 		if /\.ico$/ =~ @conf.icon then
-			%Q[<link rel="shortcut icon" href="#{CGI::escapeHTML @conf.icon}">]
+			%Q[<link rel="shortcut icon" href="#{h @conf.icon}">]
 		else
-			%Q[<link rel="icon" href="#{CGI::escapeHTML @conf.icon}">]
+			%Q[<link rel="icon" href="#{h @conf.icon}">]
 		end
 	else
 		''
@@ -335,7 +362,7 @@ end
 
 def description_tag
 	if @conf.description and not(@conf.description.empty?) then
-		%Q[<meta name="description" content="#{CGI::escapeHTML @conf.description}">]
+		%Q[<meta name="description" content="#{h @conf.description}">]
 	else
 		''
 	end
@@ -345,20 +372,35 @@ def theme_url; 'theme'; end
 
 def css_tag
 	if @mode =~ /conf$/ then
-		css = "#{theme_url}/conf.css"
+		css = "#{h theme_url}/conf.css"
 	elsif @conf.theme and @conf.theme.length > 0
-		css = "#{theme_url}/#{@conf.theme}/#{@conf.theme}.css"
+		css = "#{h theme_url}/#{h @conf.theme}/#{h @conf.theme}.css"
 	else
 		css = @css
 	end
-	title = CGI::escapeHTML( File::basename( css, '.css' ) )
+	title = File::basename( css, '.css' )
 	<<-CSS
 <meta http-equiv="content-style-type" content="text/css">
-	<link rel="stylesheet" href="#{theme_url}/base.css" type="text/css" media="all">
-	<link rel="stylesheet" href="#{css}" title="#{title}" type="text/css" media="all">
+	<link rel="stylesheet" href="#{h theme_url}/base.css" type="text/css" media="all">
+	<link rel="stylesheet" href="#{h css}" title="#{h title}" type="text/css" media="all">
 	CSS
 end
 
+def iphone_tag
+	if @conf.iphone? then
+	<<-CSS
+<meta name = "viewport" content = "width = device-width">
+	<style type="text/css"><!--
+	form.comment textarea { 
+		width: 80%;
+	}
+	--></style>
+	CSS
+	else
+		''
+	end
+end
+
 def robot_control
 	if /^form|edit|preview|showcomment$/ =~ @mode then
 		'<meta name="robots" content="noindex,nofollow">'
@@ -377,7 +419,7 @@ end
 def title_of_day( date, title )
 	r = <<-HTML
 	<span class="date">
-	<a href="#{@index}#{anchor( date.strftime( '%Y%m%d' ) )}">#{date.strftime @date_format}</a>
+	<a href="#{h @index}#{anchor( date.strftime( '%Y%m%d' ) )}">#{date.strftime @date_format}</a>
 	</span> 
 	<span class="title">#{title}</span>
 	HTML
@@ -395,7 +437,7 @@ def nyear_link( date, title )
 		d = date.strftime( '%d' )
 		years = @years.find_all {|year, months| months.include? m}
 		if years.length >= 2 then
-			%Q|#{title} <span class="nyear">[<a href="#{@index}#{anchor m + d}" title="#{nyear_diary_title date, years}">#{nyear_diary_label date, years}</a>]</span>|
+			%Q|#{title} <span class="nyear">[<a href="#{h @index}#{anchor m + d}" title="#{h(nyear_diary_title(date, years))}">#{nyear_diary_label date, years}</a>]</span>|
 		else
 			title
 		end
@@ -426,37 +468,42 @@ add_subtitle_proc do |date, index, subtitle|
 	subtitle_link( date, index, subtitle )
 end
 
+def make_category_link( subtitle )
+	r = ''
+	if subtitle
+		if respond_to?( :category_anchor ) then
+			r << subtitle.sub( /^(\[([^\[]+?)\])+/ ) do
+				$&.gsub( /\[(.*?)\]/ ) do
+					$1.split( /,/ ).collect do |c|
+						category_anchor( "#{CGI::unescapeHTML c}" )
+					end.join
+				end
+			end
+		else
+			r << subtitle
+		end
+	end
+	r
+end
+
 def subtitle_link( date, index, subtitle )
 	r = ''
 
 	if @conf.mobile_agent? then
 		r << %Q[<A NAME="p#{'%02d' % index}">*</A> ]
-		r << %Q|(#{@author})| if @multi_user and @author and subtitle
-		r << subtitle if subtitle
+		r << %Q|(#{h @author})| if @multi_user and @author and subtitle
 	else
 		if date then
 			r << "<a "
 			r << %Q[name="p#{'%02d' % index}" ] if @anchor_name
 			param = "#{date.strftime( '%Y%m%d' )}#p#{'%02d' % index}"
-			r << %Q[href="#{@index}#{anchor param}">#{@conf.section_anchor}</a> ]
+			titleattr = (not subtitle or subtitle.empty?) ? '' : %Q[ title="#{remove_tag( subtitle ).gsub( /"/, "&quot;" )}"]
+			r << %Q[href="#{h @index}#{anchor param}"#{titleattr}>#{@conf.section_anchor}</a> ]
 		end
 	
-		r << %Q[(#{@author}) ] if @multi_user and @author and subtitle
-		if subtitle
-			if respond_to?( :category_anchor ) then
-				r << subtitle.sub( /^(\[([^\[]+?)\])+/ ) do
-					$&.gsub( /\[(.*?)\]/ ) do
-						$1.split( /,/ ).collect do |c|
-							category_anchor( "#{c}" )
-						end.join
-					end
-				end
-			else
-				r << subtitle
-			end
-		end
+		r << %Q[(#{h @author}) ] if @multi_user and @author and subtitle
 	end
-	r
+	r << make_category_link( subtitle )
 end
 
 #
@@ -468,9 +515,9 @@ def my( a, str, title = nil )
 	index = /^https?:/ =~ @index ? '' : @conf.base_url
 	index += @index.sub(%r|^\./|, '')
 	if title then
-		%Q[<a href="#{index}#{anchor anc}" title="#{title}">#{str}</a>]
+		%Q[<a href="#{h index}#{anchor anc}" title="#{h title}">#{str}</a>]
 	else
-		%Q[<a href="#{index}#{anchor anc}">#{str}</a>]
+		%Q[<a href="#{h index}#{anchor anc}">#{str}</a>]
 	end
 end
 
@@ -496,36 +543,49 @@ end
 #
 # make comment form
 #
-def comment_form
-	return '' unless @mode == 'day'
+def comment_description
+   begin
+      if @options['comment_description'].length > 0 then
+         return @options['comment_description']
+      end
+   rescue
+   end
+   comment_description_default
+end
+
+def comment_form_text
+	unless @diary then
+		@diary = @diaries[@date.strftime( '%Y%m%d' )]
+		return '' unless @diary
+	end
 
 	r = ''
 	unless @conf.hide_comment_form then
 		r = <<-FORM
 			<div class="form">
 		FORM
-		if @diaries[@date.strftime('%Y%m%d')].count_comments( true ) >= @conf.comment_limit_per_day then
+		if @diary.count_comments( true ) >= @conf.comment_limit_per_day then
 			r << <<-FORM
 				<div class="caption"><a name="c">#{comment_limit_label}</a></div>
 			FORM
 		else
 			r << <<-FORM
-					<div class="caption"><a name="c">#{comment_description}</a></div>
-					<form class="comment" method="post" action="#{@conf.index}"><div>
-					<input type="hidden" name="date" value="#{ @date.strftime( '%Y%m%d' )}">
-					<div class="field name">
-						#{comment_name_label}:<input class="field" name="name" value="#{CGI::escapeHTML( @cgi.cookies['tdiary'][0] || '' )}">
-					</div>
-					<div class="field mail">
-						#{comment_mail_label}:<input class="field" name="mail" value="#{CGI::escapeHTML( @cgi.cookies['tdiary'][1] || '' )}">
-					</div>
-					<div class="textarea">
-						#{comment_body_label}:<textarea name="body" cols="60" rows="5"></textarea>
-					</div>
-					<div class="button">
-						<input type="submit" name="comment" value="#{comment_submit_label}">
-					</div>
-					</div></form>
+				<div class="caption"><a name="c">#{comment_description}</a></div>
+				<form class="comment" name="comment-form" method="post" action="#{h @index}"><div>
+				<input type="hidden" name="date" value="#{ @date.strftime( '%Y%m%d' )}">
+				<div class="field name">
+					#{comment_name_label}:<input class="field" name="name" value="#{h( @conf.to_native(@cgi.cookies['tdiary'][0] || '' ))}">
+				</div>
+				<div class="field mail">
+					#{comment_mail_label}:<input class="field" name="mail" value="#{h( @cgi.cookies['tdiary'][1] || '' )}">
+				</div>
+				<div class="textarea">
+					#{comment_body_label}:<textarea name="body" cols="60" rows="5"></textarea>
+				</div>
+				<div class="button">
+					<input type="submit" name="comment" value="#{h comment_submit_label}">
+				</div>
+				</div></form>
 			FORM
 		end
 		r << <<-FORM
@@ -535,22 +595,71 @@ def comment_form
 	r
 end
 
+add_footer_proc do
+	if @mode != 'day' or bot? then
+		''
+	elsif hide_comment_day_limit
+		r = ''
+		r << <<-JS
+			<script type="text/javascript"><!--
+			document.getElementById('comment-form-section').innerHTML = '#{comment_form_text.gsub( /[\r\n]/, '' ).gsub( /<\//, '<\\/' )}';
+			//--></script>
+		JS
+	else
+		''
+	end
+end
+
+def comment_form
+	return '' unless @mode == 'day'
+	return '' if bot?
+	return '' if hide_comment_day_limit
+
+	comment_form_text
+end
+
+def comment_form_mobile_mail_field
+	%Q|#{comment_mail_label_short}: <INPUT NAME="mail"><BR>|
+end
+
 def comment_form_mobile
 	return '' if @conf.hide_comment_form
+	return '' if bot?
+	return '' if hide_comment_day_limit
+
+	if @diaries[@date.strftime('%Y%m%d')].count_comments( true ) >= @conf.comment_limit_per_day then
+		return "<HR><P>#{comment_limit_label}</P>"
+	end
+
 	return <<-FORM
 		<HR>
-		<FORM METHOD="POST" ACTION="#{@conf.index}">
+		<FORM METHOD="POST" ACTION="#{h @index}">
 			<INPUT TYPE="HIDDEN" NAME="date" VALUE="#{@date.strftime( '%Y%m%d' )}">
 			<P>#{comment_description_short}<BR>
 			#{comment_name_label_short}: <INPUT NAME="name"><BR>
-			#{comment_mail_label_short}: <INPUT NAME="mail"><BR>
+			#{comment_form_mobile_mail_field}
 			#{comment_body_label_short}:<BR>
-			<TEXTAREA NAME="body"></TEXTAREA><BR>
+			<TEXTAREA NAME="body" COLS="100%" ROWS="5"></TEXTAREA><BR>
 			<INPUT TYPE="SUBMIT" NAME="comment" value="#{comment_submit_label_short}"></P>
 		</FORM>
 	FORM
 end
 
+def hide_comment_day_limit
+	if @conf.options.include?('spamfilter.date_limit') &&
+			@conf.options['spamfilter.date_limit'] &&
+			/\A\d+\z/ =~ @conf.options['spamfilter.date_limit'].to_s
+		date_limit = @conf.options['spamfilter.date_limit'].to_s.to_i
+		now = Time.now
+		today = Time.local(now.year, now.month, now.day)
+		limit = today - 24 * 60 * 60 * date_limit
+		if @date < limit
+			return true
+		end
+	end
+	return false
+end
+
 #
 # service methods for comment_mail
 #
@@ -574,7 +683,7 @@ def comment_mail_send
 	require 'socket'
 
 	name = comment_mail_mime( @conf.to_mail( @comment.name ) )[0]
-	body = @conf.to_mail( @comment.body.sub( /[\r\n]+\Z/, '' ) )
+	body = @comment.body.sub( /[\r\n]+\Z/, '' )
 	mail = @comment.mail
 	mail = @conf.author_mail unless mail =~ %r<[0-9a-zA-Z_.-]+@[\(\)%!0-9a-zA-Z_$@.&+-,'"*-]+>
 	mail = receivers[0] if mail.empty?
@@ -591,7 +700,7 @@ def comment_mail_send
 	mail_header = (@conf['comment_mail.header'] || '').dup
 	mail_header << ":#{@conf.date_format}" unless /%[a-zA-Z%]/ =~ mail_header
 	mail_header = @date.strftime( mail_header )
-	mail_header = comment_mail_mime( @conf.to_mail( mail_header ) ).join( "\n " ) if /[\x80-\xff]/ =~ mail_header
+	mail_header = comment_mail_mime( @conf.to_mail( mail_header ) ).join( "\n " ) #if /[\x80-\xff]/ =~ mail_header
 
 	rmail = ''
 	begin
@@ -599,7 +708,7 @@ def comment_mail_send
 	rescue
 		rmail = File::open( "#{::TDiary::PATH}/skel/mail.rtxt" ){|f| f.read }
 	end
-	text = ERB::new( rmail.untaint ).result( binding )
+	text = @conf.to_mail( ERB::new( rmail.untaint ).result( binding ) )
 	receivers.each { |i| i.untaint }
 	comment_mail( text, receivers )
 end
@@ -618,6 +727,19 @@ def comment_mail_basic_setting
 	end
 end
 
+#
+# convert to UTF-8
+#
+def to_utf8( str, charset = nil )
+	@conf.to_native( str, charset )
+end
+
+#
+# layout
+#
+def brr; '<br clear="right">'; end
+def brl; '<br clear="left">';  end
+
 #
 # preferences (saving methods)
 #
@@ -632,6 +754,7 @@ def saveconf_default
 		@conf.description = @conf.to_native( @cgi.params['description'][0] )
 		@conf.icon = @cgi.params['icon'][0]
 		@conf.banner = @cgi.params['banner'][0]
+		@conf['base_url'] = @cgi.params['base_url'][0]
 	end
 end
 
@@ -671,12 +794,12 @@ def conf_theme_list
 			select = " selected"
 			t = index
 		end
-		r << %Q|<option value="#{theme[0]}"#{select}>#{theme[1]}</option>|
+		r << %Q|<option value="#{h theme[0]}"#{select}>#{theme[1]}</option>|
 	end
 	img = t == 0 ? 'nowprinting' : @conf.theme
 	r << <<-HTML
 	</select>
-	<input name="css" size="50" value="#{ @conf.css }">
+	<input name="css" size="50" value="#{h @conf.css}">
 	</p>
 	<p><img id="theme_thumbnail" src="http://www.tdiary.org/theme.image/#{img}.jpg" alt="#{@theme_thumbnail_label}"></p>
 	<script language="JavaScript"><!--
@@ -761,7 +884,7 @@ def saveconf_csrf_protection
 			if (check_method & 2 == 2 &&
 			    (old_method & 2 == 0 || old_key != check_key))
 				@conf.save
-				raise ForceRedirect, "#{@conf.update}?conf=csrf_protection#{@cgi.referer ? '&amp;referer_exists=true' : ''}"
+				raise ForceRedirect, "#{h @update}?conf=csrf_protection#{@cgi.referer ? '&amp;referer_exists=true' : ''}"
 			end
 		end
 		err
