@@ -1,13 +1,15 @@
+# -*- coding: utf-8; -*-
 =begin
 == NAME
 tDiary: the "tsukkomi-able" web diary system.
-tdiary.rb $Revision: 1.271 $
 
-Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+Copyright (C) 2001-2009, TADA Tadashi <sho@spc.gr.jp>
 You can redistribute it and/or modify it under GPL2.
 =end
 
-TDIARY_VERSION = '2.1.4'
+TDIARY_VERSION = '2.3.3'
+
+$:.insert( 1, File::dirname( __FILE__ ).untaint + '/misc/lib' )
 
 require 'cgi'
 require 'uri'
@@ -16,6 +18,7 @@ begin
 rescue LoadError
 	require 'erb'
 end
+require 'compatible'
 
 =begin
 == String class
@@ -54,7 +57,11 @@ class CGI
 	end
 
 	def mobile_agent?
-		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode|WILLCOM)]i
+		self.user_agent =~ %r[(DoCoMo|J-PHONE|Vodafone|MOT-|UP\.Browser|DDIPOCKET|ASTEL|PDXGW|Palmscape|Xiino|sharp pda browser|Windows CE|L-mode|WILLCOM|SoftBank|Semulator|Vemulator|J-EMULATOR|emobile|mixi-mobile-converter)]i
+	end
+
+	def iphone?
+		self.user_agent =~ /iPhone|iPod/
 	end
 
 	def https?
@@ -63,7 +70,18 @@ class CGI
 	end
 
 	def request_uri
-		env_table['REQUEST_URI']
+		_request_uri = env_table['REQUEST_URI']
+		_script_name = env_table['SCRIPT_NAME']
+		if !_request_uri || _request_uri == '' || _request_uri == _script_name then
+			_path_info    = env_table['PATH_INFO'] || ''
+			_query_string = env_table['QUERY_STRING'] || ''
+			# Workaround for IIS-style PATH_INFO ('/dir/script.cgi/path', not '/path')
+			# See http://support.microsoft.com/kb/184320/
+			_request_uri = _path_info.include?(_script_name) ? '' : _script_name.dup
+			_request_uri << _path_info
+			_request_uri << '?' + _query_string if _query_string != ''
+		end
+		_request_uri
 	end
 
 	def redirect_url
@@ -97,15 +115,15 @@ module Safe
 			result = yield
 		end
 		result
-  end
-  module_function :safe
+	end
+	module_function :safe
 end
 
 #
 # module TDiary
 #
 module TDiary
-	PATH = File::dirname( __FILE__ )
+	PATH = File::dirname( __FILE__ ).untaint
 
 	#
 	# class Comment
@@ -120,7 +138,7 @@ module TDiary
 		end
 
 		def shorten( length = 120 )
-			matched = body.gsub( /\n/, ' ' ).scan( /^.{0,#{length - 2}}/ )[0]
+			matched = body.gsub( /\n/, ' ' ).scan( /^.{0,#{length - 2}}/u )[0]
 			unless $'.empty? then
 				matched + '..'
 			else
@@ -203,8 +221,8 @@ module TDiary
 			@comments.each do |com|
 				break if i >= limit and limit >= 0
 				next unless /^TrackBack$/ =~ com.name
-				i += 1
 				next unless com.visible_true?
+				i += 1
 				yield com, i
 			end
 		end
@@ -260,7 +278,11 @@ module TDiary
 
 		def each_referer( limit = 10 )
 			newer_referer
-			@referers.values.sort.reverse.each_with_index do |ary,idx|
+			# dirty workaround to avoid recursive sort that
+			# causes SecurityError in @secure=true
+			# environment since
+			# http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=16081
+			@referers.values.sort_by{|e| "%08d_%s" % e}.reverse.each_with_index do |ary,idx|
 				break if idx >= limit
 				yield ary[0], ary[1]
 			end
@@ -286,8 +308,18 @@ module TDiary
 	#
 	module Filter
 		class Filter
+			DEBUG_NONE = 0
+			DEBUG_SPAM = 1
+			DEBUG_FULL = 2
+
 			def initialize( cgi, conf )
 				@cgi, @conf = cgi, conf
+
+				if @conf.options.include?('filter.debug_mode')
+					@debug_mode = @conf.options['filter.debug_mode']
+				else
+					@debug_mode = DEBUG_NONE
+				end
 			end
 
 			def comment_filter( diary, comment )
@@ -297,6 +329,13 @@ module TDiary
 			def referer_filter( referer )
 				true
 			end
+
+			def debug( msg, level = DEBUG_SPAM )
+				return if @debug_mode == DEBUG_NONE
+				return if @debug_mode == DEBUG_SPAM and level == DEBUG_FULL
+
+				@conf.debug("#{@cgi.remote_addr}->#{(@cgi.params['date'][0] || 'no date').dump}: #{msg}")
+			end
 		end
 	end
 
@@ -305,6 +344,7 @@ module TDiary
 	#  Base module of Diary.
 	#
 	module DiaryBase
+		include ERB::Util
 		include CommentManager
 		include RefererManager
 
@@ -365,6 +405,7 @@ module TDiary
 	class PermissionError < TDiaryError; end
 	class PluginError < TDiaryError; end
 	class BadStyleError < TDiaryError; end
+	class NotFound < TDiaryError;	end
 
 	#
 	# class IOBase
@@ -425,7 +466,7 @@ module TDiary
 			load
 
 			instance_variables.each do |v|
-				v.sub!( /@/, '' )
+				v = v.to_s.sub( /@/, '' )
 				instance_eval( <<-SRC
 					def #{v}
 						@#{v}
@@ -437,16 +478,26 @@ module TDiary
 				)
 			end
 
-			bot = ["googlebot", "Hatena Antenna", "moget@goo.ne.jp"]
+			bot = ["bot", "spider", "antenna", "crawler", "moget", "slurp"]
 			bot += @options['bot'] || []
 			@bot = Regexp::new( "(#{bot.uniq.join( '|' )})", true )
+
+			# create log directory
+			require 'fileutils'
+			require 'logger'
+
+			log_path = @options['log_path'] || "#{@data_path}/log/"
+			FileUtils::mkdir_p( log_path ) unless FileTest::directory?( log_path ) 
+
+			log_file = log_path + "debug.log"
+			@logger = Logger::new( log_file, 'daily' )
 		end
 
 		# saving to tdiary.conf in @data_path
 		def save
 			result = ERB::new( File::open( "#{PATH}/skel/tdiary.rconf" ){|f| f.read }.untaint ).result( binding )
 			result.untaint unless @secure
-			Safe::safe( @secure ? 4 : 1 ) do
+			Safe::safe( @secure ? 4 : TDIARY_SAFE_NORMAL ) do
 				eval( result, binding, "(TDiary::Config#save)", 1 )
 			end
 			File::open( "#{@data_path}tdiary.conf", 'w' ) do |o|
@@ -458,10 +509,29 @@ module TDiary
 			@cgi.mobile_agent?
 		end
 
+		def iphone?
+			@cgi.iphone?
+		end
+
 		def bot?
 			@bot =~ @cgi.user_agent
 		end
 
+		def debug( str, level = "DEBUG")
+			case( level )
+			when "FATAL"
+				@logger.fatal( str )
+			when "ERROR"
+				@logger.error( str )
+			when "WARN"
+				@logger.warn( str )
+			when "INFO"
+				@logger.info( str )
+			else 
+				@logger.debug( str )			
+			end
+		end
+
 		#
 		# get/set/delete plugin options
 		#
@@ -479,14 +549,28 @@ module TDiary
 		end
 
 		def base_url
+			begin
+				if @options['base_url'].length > 0 then
+					return @options['base_url']
+				end
+			rescue
+			end
+			base_url_auto
+		end
+
+		def base_url_auto
 			return '' unless @cgi.script_name
-			if @cgi.https?
-				port = (@cgi.server_port == 443) ? '' : ':' + @cgi.server_port.to_s
-				"https://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
-			else
-				port = (@cgi.server_port == 80) ? '' : ':' + @cgi.server_port.to_s
-				"http://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
-			end.sub(%r|/+$|, '/')
+			begin
+				if @cgi.https?
+					port = (@cgi.server_port == 443) ? '' : ':' + @cgi.server_port.to_s
+					"https://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
+				else
+					port = (@cgi.server_port == 80) ? '' : ':' + @cgi.server_port.to_s
+					"http://#{ @cgi.server_name }#{ port }#{File::dirname(@cgi.script_name)}/"
+				end.sub(%r|/+$|, '/')
+			rescue SecurityError
+				''
+			end
 		end
 
 	private
@@ -564,27 +648,47 @@ module TDiary
 			@data_path += '/' if /\/$/ !~ @data_path
 			raise TDiaryError, 'Do not set @data_path as same as tDiary system directory.' if @data_path == "#{PATH}/"
 
-			variables = [
-				:html_title, :author_name, :author_mail, :index_page, :hour_offset,
-				:description, :icon, :banner,
-				:header, :footer,
-				:section_anchor, :comment_anchor, :date_format, :latest_limit, :show_nyear,
-				:theme, :css,
-				:show_comment, :comment_limit, :comment_limit_per_day,
-				:mail_on_comment, :mail_header,
-				:show_referer, :no_referer2, :only_volatile2, :referer_table2,
-				:options2,
-			]
 			begin
+				def_vars1 = ''
+				def_vars2 = ''
+				[
+					:tdiary_version,
+					:html_title, :author_name, :author_mail, :index_page, :hour_offset,
+					:description, :icon, :banner,
+					:header, :footer,
+					:section_anchor, :comment_anchor, :date_format, :latest_limit, :show_nyear,
+					:theme, :css,
+					:show_comment, :comment_limit, :comment_limit_per_day,
+					:mail_on_comment, :mail_header,
+					:show_referer, :no_referer2, :only_volatile2, :referer_table2,
+					:options2,
+				].each do |var|
+					def_vars1 << "#{var} = nil\n"
+					def_vars2 << "@#{var} = #{var} unless #{var} == nil\n"
+				end
+
 				cgi_conf = File::open( "#{@data_path}tdiary.conf" ){|f| f.read }
 				cgi_conf.untaint unless @secure
-				def_vars = ""
-				variables.each do |var| def_vars << "#{var} = nil\n" end
-				eval( def_vars )
-				Safe::safe( @secure ? 4 : 1 ) do
-					eval( cgi_conf, binding, "(TDiary::Config#cgi_conf)", 1 )
+
+				b = binding.taint
+				eval( def_vars1, b )
+				Safe::safe( @secure ? 4 : TDIARY_SAFE_NORMAL ) do
+					begin
+						eval( cgi_conf, b, "(TDiary::Config#load_cgi_conf)", 1 )
+					rescue SyntaxError
+						enc = case @lang
+							when 'en'
+								'UTF-8'
+							when 'zh'
+								'Big5'
+							else
+								'EUC-JP'
+							end
+						cgi_conf.force_encoding( enc )
+						retry
+					end
 				end
-				variables.each do |var| eval "@#{var} = #{var} if #{var} != nil" end
+				eval( def_vars2, b )
 			rescue IOError, Errno::ENOENT
 			end
 		end
@@ -610,6 +714,7 @@ module TDiary
 	#  plugin management class
 	#
 	class Plugin
+		include ERB::Util
 		attr_reader :cookies
 
 		def initialize( params )
@@ -664,6 +769,8 @@ module TDiary
 					load_plugin( file )
 					@plugin_files << plugin_file
 				end
+			rescue ::TDiary::ForceRedirect
+				raise
 			rescue Exception
 				raise PluginError::new( "Plugin error in '#{File::basename( plugin_file )}'.\n#{$!}\n#{$!.backtrace[0]}" )
 			end
@@ -694,7 +801,7 @@ module TDiary
 			@section_enter_procs.taint
 			@subtitle_procs.taint
 			@section_leave_procs.taint
-			return Safe::safe( secure ? 4 : 1 ) do
+			return Safe::safe( secure ? 4 : TDIARY_SAFE_NORMAL ) do
 				eval( src, binding, "(TDiary::Plugin#eval_src)", 1 )
 			end
 		end
@@ -876,9 +983,9 @@ module TDiary
 
 		def conf_current_style( key )
 			if key == @cgi.params['conf'][0] then
-				' class="current"'
+				'selected'
 			else
-				''
+				'other'
 			end
 		end
 
@@ -890,12 +997,16 @@ module TDiary
 			end
 		end
 
+		def remove_tag( str )
+			str.gsub( /<[^"'<>]*(?:"[^"]*"[^"'<>]*|'[^']*'[^"'<>]*)*(?:>|(?=<)|$)/, '' )
+		end
+
 		def apply_plugin( str, remove_tag = false )
 			return '' unless str
 			r = str.dup
 			if @options['apply_plugin'] and str.index( '<%' ) then
 				r = str.untaint if $SAFE < 3
-				Safe::safe( @conf.secure ? 4 : 1 ) do
+				Safe::safe( @conf.secure ? 4 : TDIARY_SAFE_NORMAL ) do
 					begin
 						r = ERB::new( r ).result( binding )
 					rescue Exception
@@ -903,7 +1014,7 @@ module TDiary
 					end
 				end
 			end
-			r.gsub!( /<[^"'<>]*(?:"[^"]*"[^"'<>]*|'[^']*'[^"'<>]*)*(?:>|(?=<)|$)/, '' ) if remove_tag
+			r = remove_tag( r ) if remove_tag
 			r
 		end
 
@@ -912,7 +1023,7 @@ module TDiary
 			str = nil
 			table.each do |url, name|
 				if /#{url}/i =~ ref then
-					str = ref.gsub( /#{url}/in, name )
+					str = ref.gsub( /#{url}/i, name )
 					break
 				end
 			end
@@ -923,6 +1034,10 @@ module TDiary
 			@conf.bot?
 		end
 
+		def help( name )
+			%Q[<div class="help-icon"><a href="http://docs.tdiary.org/#{h @conf.lang}/?#{h name}" target="_blank"><img src="#{theme_url}/help.png" width="19" height="19" alt="Help"></a></div>]
+		end
+
 		def method_missing( *m )
 			super if @debug
 			# ignore when no plugin
@@ -948,6 +1063,8 @@ module TDiary
 	#  tDiary CGI
 	#
 	class TDiaryBase
+		include ERB::Util
+
 		DIRTY_NONE = 0
 		DIRTY_DIARY = 1
 		DIRTY_COMMENT = 2
@@ -1024,7 +1141,12 @@ module TDiary
 						File::open( path ) {|f| f.read }
 					end
 				}.join
-				r = ERB::new( rhtml.untaint ).result( binding )
+				begin
+					r = ERB::new( rhtml.untaint ).result( binding )
+				rescue Encoding::CompatibilityError
+					# migration error on ruby 1.9 only 1st time, reload.
+					raise ForceRedirect::new( @conf.base_url )
+				end
 				r = ERB::new( r ).src
 				store_cache( r, prefix ) unless @diaries.empty?
 			end
@@ -1156,17 +1278,21 @@ module TDiary
 			end
 		end
 
+		def all_filters
+			load_filters
+			@filters + (load_plugins.sf_filters || [])
+		end
+
 		def comment_filter( diary, comment )
-			load_filters unless @filters
-			@filters.each do |filter|
+			all_filters.each do |filter|
 				return false unless filter.comment_filter( diary, comment )
+				break unless comment.visible?
 			end
 			true
 		end
 
 		def referer_filter( referer )
-			load_filters unless @filters
-			@filters.each do |filter|
+			all_filters.each do |filter|
 				return false unless filter.referer_filter( referer )
 			end
 			true
@@ -1206,7 +1332,7 @@ module TDiary
 			updaterb_regexp = '' unless updaterb_regexp
 
 			if (masterkey != '' && check_key)
-				@csrf_protection="<input type=\"hidden\" name=\"csrf_protection_key\" value=\"#{CGI::escapeHTML(masterkey)}\">"
+				@csrf_protection = %Q[<input type="hidden" name="csrf_protection_key" value="#{h masterkey}">]
 			else
 				@csrf_protection="<!-- no CSRF protection key used -->"
 			end
@@ -1252,9 +1378,9 @@ Security Error: Possible Cross-site Request Forgery (CSRF)
                     - GET is #{ csrf_protection_get_is_okay ? '' : 'not '}allowed
                 - Request Method is #{ is_post ? 'POST' : 'not POST' }
                 - Referer is #{ referer_is_empty ? 'empty' : referer_is_config ? 'config' : 'another page' }
-                    - Given referer:       #{ CGI::escapeHTML( referer_uri.to_s )}
-                    - Expected base URI:   #{ CGI::escapeHTML( base_uri.to_s )}
-                    - Expected update URI: #{ CGI::escapeHTML( config_uri.to_s )}
+                    - Given referer:       #{h referer_uri.to_s}
+                    - Expected base URI:   #{h base_uri.to_s}
+                    - Expected update URI: #{h config_uri.to_s}
                 - CSRF key is #{ is_key_ok ? 'OK' : given_key ? 'NG (' + (given_key || '') + ')' : 'nothing' }
 EOS
 		end
@@ -1293,7 +1419,16 @@ EOS
 			rescue TDiaryError
 			end
 			@date = Time::now + (@conf.hour_offset * 3600).to_i
-			@diary = @io.diary_factory( @date, '', '', @conf.style )
+			title = ''
+			@io.transaction( @date ) do |diaries|
+				@diaries = diaries
+				diary = self[@date]
+				if diary then
+					title = diary.title
+				end
+				DIRTY_NONE
+			end
+			@diary = @io.diary_factory( @date, title, '', @conf.style )
 		end
 	end
 
@@ -1510,7 +1645,7 @@ EOS
 
 		def initialize( cgi, rhtml, conf )
 			super
-			@key = @cgi.params['conf'][0]
+			@key = @cgi.params['conf'][0] || ''
 		end
 	end
 
@@ -1567,6 +1702,7 @@ EOS
 					end
 					dirty
 				end
+				@date = @diary.date if @diary
 			end
 		end
 
@@ -1628,7 +1764,8 @@ EOS
 			super
 			begin
 				# time is noon for easy to calc leap second.
-				load( Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)$/ )[0] ) + 12*60*60 )
+				@date = Time::local( *@cgi.params['date'][0].scan( /^(\d{4})(\d\d)(\d\d)$/ )[0] ) + 12*60*60
+				load( @date )
 			rescue ArgumentError, NameError
 				raise TDiaryError, 'bad date'
 			end
@@ -1639,14 +1776,21 @@ EOS
 			@diary ? @diary.last_modified : Time::at( 0 )
 		end
 
+		def eval_rhtml( prefix = '' )
+			if not @diary and @conf.bot?
+				raise NotFound
+			else
+				super(prefix)
+			end
+		end
+
 	protected
 		def load( date )
 			if not @diary or (@diary.date.dup + 12*60*60).gmtime.strftime( '%Y%m%d' ) != date.dup.gmtime.strftime( '%Y%m%d' ) then
-				@date = date
-				@io.transaction( @date ) do |diaries|
+				@io.transaction( date ) do |diaries|
 					@diaries = diaries
 					dirty = DIRTY_NONE
-					@diary = self[@date]
+					@diary = self[date]
 					if @diary and @cgi.referer then
 						@diary.add_referer( @cgi.referer )
 						dirty = DIRTY_REFERER
@@ -1654,8 +1798,7 @@ EOS
 					dirty
 				end
 			else
-				@date = date
-				@diary = self[@date]
+				@diary = self[date]
 			end
 		end
 
@@ -1715,11 +1858,25 @@ EOS
 		end
 	end
 
+	#
+	# class TDiaryMonthBase
+	#  base of TDiaryMonth and TDiaryNYear
+	#
+	class TDiaryMonthBase < TDiaryView
+		def eval_rhtml( prefix = '' )
+			if @diaries.empty? and @conf.bot?
+				raise NotFound
+			else
+				super(prefix)
+			end
+		end
+	end
+	
 	#
 	# class TDiaryMonth
 	#  show month mode view
 	#
-	class TDiaryMonth < TDiaryView
+	class TDiaryMonth < TDiaryMonthBase
 		def initialize( cgi, rhtml, conf )
 			super
 
@@ -1750,7 +1907,7 @@ EOS
 	# class TDiaryNYear
 	#  show nyear mode view
 	#
-	class TDiaryNYear < TDiaryView
+	class TDiaryNYear < TDiaryMonthBase
 		def initialize(cgi, rhtml, conf)
 			super
 
@@ -1800,7 +1957,14 @@ EOS
 						@date = @diary.date if @diary
 					end
 					unless @diary then
-						@diary = @diaries[@diaries.keys.sort.reverse[0]]
+						@diaries.keys.sort.reverse_each do |d|
+							diary = @diaries[d]
+							if diary.visible?
+								@diary = diary
+								break
+							end
+						end
+						@diary = @diaries[@diaries.keys.sort.reverse[0]] unless @diary
 						@date = @diary.date if @diary
 					end
 					DIRTY_NONE
@@ -1939,6 +2103,18 @@ EOS
 		end
 	end
 
+	#
+	# class TDiarySearch
+	#  base of search view mode classes
+	#
+	class TDiarySearch < TDiaryBase
+		attr_reader :last_modified
+		def initialize(cgi, rhtml, conf)
+			super
+			@last_modified = Time.now
+		end
+	end
+
 	#
 	# exception class for TrackBack
 	#
@@ -1958,6 +2134,7 @@ EOS
 			else
 				@date = Time::now
 			end
+			@cgi.params['date'] = [@date.strftime( '%Y%m%d' )]
 		end
 
 		def diary_url
@@ -1978,64 +2155,12 @@ HERE
 <?xml version="1.0" encoding="iso-8859-1"?>
 <response>
 <error>1</error>
-<message>#{reason}</message>
+<message>#{CGI::escapeHTML reason}</message>
 </response>
 HERE
 		end
 	end
 
-	#
-	# class TDiaryTrackBackRSS
-	#  generate RSS
-	#
-	class TDiaryTrackBackRSS < TDiaryTrackBackBase
-		def initialize( cgi, rhtml, conf )
-			super
-			@io.transaction( @date ) do |diaries|
-				@diaries = diaries
-				@diary = @diaries[@date.strftime('%Y%m%d')]
-				DIRTY_NONE
-			end
-		end
-
-		def eval_rhtml( prefix = '' )
-			raise TDiaryTrackBackError.new("invalid date: #{@date.strftime('%Y%m%d')}") unless @diary
-			load_plugins
-			r = <<RSSHEAD
-<?xml version="1.0" encoding="#{@conf.encoding}"?>
-<response>
-<error>0</error>
-<rss version="0.91">
-<channel>
-<title>#{@diary.title}</title>
-<link>#{diary_url}</link>
-<description></description>
-<language>#{@conf.html_lang}</language>
-RSSHEAD
-			@diary.each_comment do |com, idx|
-				begin
-					next unless com.visible_true?
-				rescue NameError, NoMethodError
-					next unless com.visible?
-				end
-				next unless /^(TrackBack|Pingback)$/ =~ com.name
-				url, blog_name, title, excerpt = com.body.split(/\n/, 4)
-				r << <<RSSITEM
-<item>
-<title>#{CGI::escapeHTML( title )}</title>
-<link>#{CGI::escapeHTML( url )}</link>
-<description>#{CGI::escapeHTML( excerpt )}</description>
-</item>
-RSSITEM
-			end
-			r << <<RSSFOOT
-</channel>
-</rss>
-</response>
-RSSFOOT
-		end
-	end
-
 	#
 	# class TDiaryTrackBackReceive
 	#  receive TrackBack ping and store as comment
@@ -2045,10 +2170,15 @@ RSSFOOT
 			super
 			@error = nil
 
+			charset = nil
+			if @cgi.content_type =~ /charset=([^\s;]*)/i then
+				charset = $1
+			end
+			
 			url = @cgi.params['url'][0]
-			blog_name = @conf.to_native( @cgi.params['blog_name'][0] || '' )
-			title = @conf.to_native( @cgi.params['title'][0] || '' )
-			excerpt = @conf.to_native( @cgi.params['excerpt'][0] || '' )
+			blog_name = @conf.to_native( @cgi.params['blog_name'][0] || '', charset )
+			title = @conf.to_native( @cgi.params['title'][0] || '', charset )
+			excerpt = @conf.to_native( @cgi.params['excerpt'][0] || '', charset )
 			if excerpt.length > 255
 				excerpt = @conf.shorten( excerpt, 252 )
 			end
@@ -2064,8 +2194,12 @@ RSSFOOT
 					@diary = @diaries[@date.strftime('%Y%m%d')]
 					if @diary and comment_filter( @diary, @comment ) then
 						@diary.add_comment(@comment)
+						unless @comment.visible?
+							@error = 'Your TrackBack has been filtered (maybe).'
+						end
 						DIRTY_COMMENT
 					else
+						@error = 'Your TrackBack has been filtered.'
 						@comment = nil
 						DIRTY_NONE
 					end
