@@ -1,3 +1,4 @@
+# -*- coding: utf-8; -*-
 #
 # default.rb: included TDiary::Filter::DefaultFilter class
 #
@@ -9,7 +10,7 @@ module TDiary
 	module Filter
 		class DefaultFilter < Filter
 			def comment_filter( diary, comment )
-				if /post/i !~ @cgi.request_method then
+				if 'POST' != @cgi.request_method then
 					return false
 				end
 				if comment.name.strip.empty? or comment.body.strip.empty? then
@@ -27,8 +28,8 @@ module TDiary
 			def referer_filter( referer )
 				if not referer then
 					false
-				elsif /[\x00-\x20\x7f-\xff]/ =~ referer then
-					false
+				#elsif /[\x00-\x20\x7f-\xff]/ =~ referer then
+				#	false
 				elsif @conf.bot?
 					false
 				elsif %r|^https?://|i =~ referer
