@@ -1,15 +1,11 @@
+# -*- coding: utf-8; -*-
 #
-# tDiary language setup: English(en) $Revision: 1.3 $
+# tDiary language setup: English(en) $Revision: 1.5 $
 #
 # Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
-#
-# setting ruby charctor encoding.
-# 
-$KCODE = 'n'
-
 #
 # 'html_lang' method returns String of HTML language attribute.
 # 
@@ -21,19 +17,31 @@ end
 # 'encoding' method returns String of HTTP or HTML charactor encoding.
 # 
 def encoding
-	'ISO-8859-1'
+	'UTF-8'
 end
 
+def encoding_old
+	'UTF-8'
+end
+
+
 #
 # 'mobile_encoding' method returns charactor encoding in mobile mode.
 def mobile_encoding
-	'ISO-8859-1'
+	'UTF-8'
 end
 
 #
 # 'to_native' method converts string automatically to native encoding.
 # 
-def to_native( str )
+def to_native( str, charset = nil )
+	str.dup
+end
+
+#
+# 'migrate_to_utf8' method converts string to UTF-8, but dummy in en.
+#
+def migrate_to_utf8( str )
 	str.dup
 end
 
