@@ -1,15 +1,11 @@
+# -*- coding: utf-8; -*-
 #
-# tDiary language setup: (zh) $Revision: 1.2 $
+# tDiary language setup: (zh) $Revision: 1.4 $
 #
 # Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
 
-#
-# setting ruby charctor encoding.
-# 
-$KCODE = 'n'
-
 #
 # 'html_lang' method returns String of HTML language attribute.
 # 
@@ -21,22 +17,35 @@ end
 # 'encoding' method returns String of HTTP or HTML charactor encoding.
 # 
 def encoding
-	'Big5'
+	'UTF-8'
 end
 
 #
 # 'mobile_encoding' method returns charactor encoding in mobile mode.
 def mobile_encoding
+	'UTF-8'
+end
+
+def encoding_old
 	'Big5'
 end
 
+
 #
 # 'to_native' method converts string automatically to native encoding.
 # 
-def to_native( str )
+def to_native( str, charset = nil )
 	str.dup
 end
 
+#
+# 'migrate_to_utf8' method converts string to UTF-8
+#
+def migrate_to_utf8( str )
+	require 'iconv'
+	Iconv::iconv( encoding, encoding_old, str )
+end
+
 #
 # 'to_mobile' method converts string automatically to mobile mode encoding.
 # 
